import React from 'react';
import {
    SafeAreaView,
    ScrollView,
    StatusBar,
    StyleSheet,
    Text,
    Image,
    TouchableOpacity,
    View,
    DeviceEventEmitter
} from 'react-native';
import FastImage from 'react-native-fast-image';
import { TextInput } from 'react-native-gesture-handler';
import Animated, { useAnimatedStyle, useSharedValue, withSpring, withTiming } from 'react-native-reanimated';
import { BjInstanceActualMeasurementResearchTableRow, BjInstanceSampleSquareResearch } from '../../database/Instance';
import { colors, deepCopy, dispatchSerialNumber, getCurrentDateNs, handleDismissKeyboard, isEmpty, onePx, px2dp, toastShort, validResponseCode } from '../../utils';
import { generateResearchCode } from '../../utils/generate';
import { BjTypeActualMeasurementResearchTableRow, BjTypeLocation, BjTypeSampleSquareResearch } from '../../utils/types';
import KitCheckBox from '../kits/KitCheckBox';
import KitFormGroupRow from '../kits/KitFormGroupRow';
import KitImageListView from '../kits/KitImageListView';
import NormalActionSheet from '../kits/NormalActionSheet';
import KitLoadingImage from '../kits/KitLoadingImage';
import API from '../../api';
import KitSerialNumberInputToast from '../kits/KitSerialNumberInputToast';
import MainSampleSizeSettingDialog from './MainSampleSizeSettingDialog';
import KitAreaLocaionMsg from '../kits/KitAreaLocaionMsg';

interface Props {
}

interface State {
    tempResearchInstance: BjTypeSampleSquareResearch
}


interface TypeResearch {
    name: string
    type: string
}

const AddSampleSquareResearchDialog = (props: Props) => {
    const containerRef = React.useRef(null);
    const delayTimer = React.useRef(null);
    const delayTimer1 = React.useRef(null);
    const overlayOpacity = useSharedValue(0.1);
    const layoutScaleValue = useSharedValue(0);
    const [loading, setLoading] = React.useState(false);
    const [tempResearchInstance, setTempResearchInstance] = React.useState<BjTypeSampleSquareResearch>(deepCopy(BjInstanceSampleSquareResearch));
    const [refresh, setRefresh] = React.useState(false);
    const showToastListener = React.useRef(null);
    const hideToastListener = React.useRef(null);
    const tempKey = React.useRef(null);
    const tempPropName = React.useRef(null);
    const actionSheetRef = React.useRef(null);
    const kitImageListViewRef = React.useRef(null);
    const serialNumberToastRef = React.useRef(null);
    const targetSpeciesLiveTypeSheetRef = React.useRef(null);
    const onSampleSizeSetttingFinishListener = React.useRef(null);
    const kitAreaLocaionMsgRef = React.useRef(null);

    React.useEffect(() => {
        overlayOpacity.value = withTiming(0.2);
        layoutScaleValue.value = withSpring(0.6);
        showToastListener.current = DeviceEventEmitter.addListener('show-sample-square-research-dialog', (a) => {
            const { researchInstance } = a;
            if (researchInstance && researchInstance.id) {
                setTempResearchInstance(deepCopy(researchInstance));
                if (researchInstance.researchAreaImageList) {
                    kitImageListViewRef.current.setImageList(researchInstance.researchAreaImageList)
                }
            } else {
                handleGenerateResearchCode();
                setTempResearchInstance(deepCopy(BjInstanceSampleSquareResearch));
            }
            delayTimer.current = setTimeout(() => {
                handleShowToast()
            }, 0);

        });
        hideToastListener.current = DeviceEventEmitter.addListener('hide-show-sample-square-research-dialog', (a) => {
            handleHideToast()
        });
        onSampleSizeSetttingFinishListener.current = DeviceEventEmitter.addListener('on-main-sample-size-setting-dialog-finish', (a) => {
            setTempResearchInstance(deepCopy(a.tempResearchInstance))
        })
        return () => {
            delayTimer.current && clearTimeout(delayTimer.current);
            delayTimer1.current && clearTimeout(delayTimer1.current);
            showToastListener.current && showToastListener.current?.remove();
            hideToastListener.current && hideToastListener.current?.remove();
        }
    }, []);

    const handleGenerateResearchCode = async () => {
        const serialNumberAndCode = await generateResearchCode('sampleSquareResearch');
        if (serialNumberAndCode) {
            tempResearchInstance.serialNumberAndCode = serialNumberAndCode;
            tempResearchInstance.createDate = getCurrentDateNs();
            setTempResearchInstance(deepCopy(tempResearchInstance))
        }
    }

    const handleShowToast = () => {
        setRefresh(false);
        requestAnimationFrame(() => {
            containerRef.current.setNativeProps({
                style: {
                    width: '100%',
                    height: '100%'
                }
            })
            delayTimer1.current = setTimeout(() => {
                overlayOpacity.value = 0.52;
                layoutScaleValue.value = 1;
            }, 0);
        })
    };

    const handleHideToast = () => {
        delayTimer.current = setTimeout(() => {
            containerRef.current.setNativeProps({
                style: {
                    width: 0,
                    height: 0
                }
            })
        }, 240);
        overlayOpacity.value = 0.1;
        layoutScaleValue.value = 0;
        kitImageListViewRef.current.setImageList([]);
        setRefresh(true);
        handleDismissKeyboard();
    }

    const handleComfirmToast = async () => {
        if (!checkParamsReady()) {
            return false;
        };
        setLoading(true);
        let params = tempResearchInstance;
        params.belongType = 'sample-line';
        const researchAreaImageList = kitImageListViewRef.current.getImageList();
        params.researchAreaImageList = JSON.stringify(researchAreaImageList);
        const location: BjTypeLocation = kitAreaLocaionMsgRef.current.getLocation();
        if (location && location.latitude) {
            params.latitudeStart = location.latitude;
            params.longitudeStart = location.longitude;
            params.altitudeStart = location.altitude;
        }
        const researchOptionRes = await API.optionSampleSquareResearchV1(params);
        if (validResponseCode(researchOptionRes)) {
            setLoading(false)
            console.log("researchOptionRes", researchOptionRes)
            if (tempResearchInstance && tempResearchInstance.id) {
                //保存
                const currentSampleSquareResearchId = researchOptionRes.data.info;
                DeviceEventEmitter.emit('on-sample-square-research-edit', { tempResearchInstance: tempResearchInstance })
                toastShort("保存成功！")
            } else {
                //新增
                const currentSampleSquareResearchId = researchOptionRes.data.info;
                DeviceEventEmitter.emit('on-sample-square-research-finish', {
                    key: tempKey.current,
                    currentSampleSquareResearchId: currentSampleSquareResearchId
                })
                toastShort("添加成功！")
            }
            handleHideToast();
        } else {
            setLoading(false)
        }
    }


    const overlayAnimatedStyle = useAnimatedStyle(() => {
        return {
            opacity: withTiming(overlayOpacity.value, { duration: 240 })
        }
    });

    const toastBodyAnimatedStyle = useAnimatedStyle(() => {
        return {
            transform: [
                {
                    scale: withSpring(layoutScaleValue.value, { stiffness: 96 }),
                }
            ],
            opacity: withTiming(layoutScaleValue.value, { duration: 120 }),
        }
    })

    const _setMainSampleSizeSettingType = (type) => {
        let _tempResearchInstance = deepCopy(tempResearchInstance);
        _tempResearchInstance.mainSampleSizeSettingType = type;
        console.log("_tempResearchInstance", _tempResearchInstance)
        setTempResearchInstance(_tempResearchInstance);
    };

    const _showSerialNumberToast = () => {
        serialNumberToastRef.current.show();
    };

    const _adaptTargetSpeciesLiveType = (type) => {
        const options = [
            {
                key: 1,
                value: 'arbor',
                name: '乔木',
            },
            {
                key: 2,
                value: 'shrub',
                name: '灌木',
            },
            {
                key: 3,
                value: 'plant',
                name: '草本',
            },
            {
                key: 4,
                value: 'moss',
                name: '苔藓',
            },
        ];
        const findOption = options.find(option => {
            return option.value == type;
        });
        if (findOption) {
            return findOption.name
        }
        return "";
    };

    const _onSubSampleSquareMaxNumTextChange = (text) => {
        let _tempResearchInstance = deepCopy(tempResearchInstance);
        _tempResearchInstance.subSampleSquareMaxNum = text;
        setTempResearchInstance(deepCopy(_tempResearchInstance))
    }

    const _handleShowMainSampleSizeSettingDialog = () => {
        if (isEmpty(tempResearchInstance.targetSpeciesLiveType)) {
            return toastShort("请选择目标物种生活型")
        }
        DeviceEventEmitter.emit('show-main-sample-size-setting-dialog', {
            tempResearchInstance: tempResearchInstance
        })
    };

    const _adaptMainSampleSize = () => {
        if (tempResearchInstance.mainSampleSizeSettingType == 'sample-square') {
            if (isEmpty(tempResearchInstance.sampleSquareLong) && isEmpty(tempResearchInstance.sampleSquareWidth)) {
                return "";
            }
            return `${tempResearchInstance.sampleSquareLong}m x ${tempResearchInstance.sampleSquareWidth}m`
        } else {
            if (isEmpty(tempResearchInstance.sampleRoundRadius)) {
                return "";
            }
            return `${tempResearchInstance.sampleRoundRadius}m`
        }
    }

    const checkParamsReady = () => {
        if (isEmpty(tempResearchInstance.targetSpeciesLiveType)) {
            toastShort("请选择目标物种生物型")
            return false;
        }
        if (isEmpty(_adaptMainSampleSize())) {
            toastShort("请设置主样方(圆)大小")
            return false;
        }
        if (isEmpty(tempResearchInstance.subSampleSquareMaxNum)) {
            toastShort("请输入副样方(圆)数")
            return false;
        }
        return true;
    }

    const _onTargetSpeciesLiveTypeSheetChange = (e) => {
        let _tempResearchInstance = tempResearchInstance;
        _tempResearchInstance.targetSpeciesLiveType = e.value;
        switch (e.value) {
            case 'arbor':
                _tempResearchInstance.sampleSquareLong = '20';
                _tempResearchInstance.sampleSquareWidth = '20';
                _tempResearchInstance.sampleRoundRadius = '15';
                break;
            case 'shrub':
                _tempResearchInstance.sampleSquareLong = '5';
                _tempResearchInstance.sampleSquareWidth = '5';
                _tempResearchInstance.sampleRoundRadius = '5';
                break;
            case 'plant':
                _tempResearchInstance.sampleSquareLong = '1';
                _tempResearchInstance.sampleSquareWidth = '1';
                _tempResearchInstance.sampleRoundRadius = '1';
                break;
            case 'moss':
                _tempResearchInstance.sampleSquareLong = '1';
                _tempResearchInstance.sampleSquareWidth = '1';
                _tempResearchInstance.sampleRoundRadius = '1';
                break;
            default:
                break;
        }
        setTempResearchInstance(deepCopy(tempResearchInstance));
    }

    const _onResearchCodeSerailNumberChange = (e) => {
        let _tempResearchInstance = tempResearchInstance;
        let serialNumberAndCode = e.code + '-' + e.serialNumber;
        tempResearchInstance.serialNumberAndCode = serialNumberAndCode;
        setTempResearchInstance(deepCopy(_tempResearchInstance))
    };

    return (
        <View
            ref={containerRef}
            style={styles.container}
        >
            <View style={styles.content}>
                <Animated.View style={[styles.toastBody, toastBodyAnimatedStyle]}>
                    <View style={styles.dialogHeader}>
                        <Text style={{ fontSize: 15 }}>{
                            tempResearchInstance && tempResearchInstance.id ?
                                '编辑关联样方(圆)'
                                :
                                '快速添加样方(圆)'
                        }</Text>
                    </View>
                    <View style={styles.group}>
                        <KitFormGroupRow
                            leftTitle={"调查编号"}
                            leftType={'pick'}
                            leftValue={tempResearchInstance.serialNumberAndCode}
                            onPressLeft={_showSerialNumberToast}
                            rightTitle={"调查人员"}
                            rightType={'text'}
                            rightValue={"风声"}
                            hideRightRightIcon
                            inlineLayout
                            isLeftNeeded
                            isRightNeeded
                        />
                        <KitFormGroupRow
                            leftTitle={"主样方(圆)编号"}
                            leftType={'pick'}
                            leftValue={tempResearchInstance.serialNumberAndCode + '-01'}
                            isLeftNeeded
                            rightTitle={"目标物种生活型"}
                            rightPlaceholderText={"请选择"}
                            rightType={'pick'}
                            rightValue={_adaptTargetSpeciesLiveType(tempResearchInstance.targetSpeciesLiveType)}
                            onPressRight={() => {
                                tempResearchInstance && tempResearchInstance.id ?
                                    toastShort("目标物种生活型不能修改")
                                    :
                                    targetSpeciesLiveTypeSheetRef.current.show()
                            }}
                            isRightNeeded
                            keepLeftTitle
                            inlineLayout
                        />
                        <KitFormGroupRow
                            leftTitle={"主样方(圆)大小"}
                            leftType={'pick'}
                            leftValue={_adaptMainSampleSize()}
                            leftPlaceholderText={"请选择"}
                            onPressLeft={_handleShowMainSampleSizeSettingDialog}
                            isLeftNeeded
                            rightTitle={"副样方(圆)数"}
                            rightPlaceholderText={"请填写"}
                            rightType={'input'}
                            rightValue={tempResearchInstance.subSampleSquareMaxNum}
                            rightTextInputType={'number'}
                            rightTextInputMaxLength={4}
                            onChangeTextRight={_onSubSampleSquareMaxNumTextChange}
                            rightValueLimitRule={['int', 'int&>0']}
                            hideRightRightIcon
                            inlineLayout
                            keepLeftTitle
                            isRightNeeded
                            isLast
                        />
                    </View>
                    <View style={styles.group}>
                        <KitImageListView
                            ref={kitImageListViewRef}
                            title={"调查区域照片"}
                            maxLengthLimit={4}
                            inlineLayout
                        />
                    </View>
                    <View style={styles.footer}>
                        <TouchableOpacity
                            onPress={handleHideToast}
                            style={styles.footerLeftBtn}
                        >
                            <Text style={{ fontSize: 14, color: colors.greenTextColor }}>取消</Text>
                        </TouchableOpacity>
                        <TouchableOpacity
                            onPress={handleComfirmToast}
                            style={styles.footerRightBtn}
                        >
                            {
                                loading ?
                                    <KitLoadingImage tintColor={'#fff'} size={px2dp(18)} />
                                    :
                                    null
                            }
                            <Text style={{ fontSize: 14, color: '#fff', marginHorizontal: px2dp(5) }}>
                                {
                                    tempResearchInstance && tempResearchInstance.id ?
                                        "保存"
                                        :
                                        "确定"
                                }
                            </Text>
                        </TouchableOpacity>
                    </View>
                </Animated.View>
                <Animated.View style={[styles.overlay, overlayAnimatedStyle]}>
                </Animated.View>
                <MainSampleSizeSettingDialog />
                <NormalActionSheet
                    ref={targetSpeciesLiveTypeSheetRef}
                    headerText={"请选择目标物种生活型"}
                    options={[
                        {
                            key: 1,
                            value: 'arbor',
                            name: '乔木',
                        },
                        {
                            key: 2,
                            value: 'shrub',
                            name: '灌木',
                        },
                        {
                            key: 3,
                            value: 'plant',
                            name: '草本',
                        },
                        {
                            key: 4,
                            value: 'moss',
                            name: '苔藓',
                        },
                    ]}
                    onChange={_onTargetSpeciesLiveTypeSheetChange}
                />
                {
                    refresh ?
                        null
                        :
                        <KitSerialNumberInputToast
                            ref={serialNumberToastRef}
                            code={dispatchSerialNumber(tempResearchInstance.serialNumberAndCode, 0)}
                            serialNumber={dispatchSerialNumber(tempResearchInstance.serialNumberAndCode, 1)}
                            onConfirm={_onResearchCodeSerailNumberChange.bind(this)}
                            leftTitle={"编号前缀"}
                            rightTitle={"序列号"}
                            leftPlaceHolder={"请输入编号前缀"}
                            rightPlaceHolder={"请输入调查序列号"}
                            title={"设置调查编号"}
                            existText={"调查编号已存在..."}
                            type={'sampleSquareResearch'}
                            notCheck={true}
                        />
                }
                <KitAreaLocaionMsg
                    ref={kitAreaLocaionMsgRef}
                    size={'headless'}
                />
            </View>
        </View>

    )
};

const styles = StyleSheet.create({
    overlay: {
        position: 'absolute',
        top: 0,
        bottom: 0,
        left: 0,
        right: 0,
        width: '100%',
        height: '100%',
        backgroundColor: '#000',
        zIndex: -1
    },

    container: {
        position: 'absolute',
        top: 0,
        bottom: 0,
        left: 0,
        right: 0,
        zIndex: 9999,
        width: 0,
        height: 0,
        overflow: 'hidden'
    },

    content: {
        position: 'relative',
        width: '100%',
        height: '100%',
        flex: 1,
        justifyContent: 'center',
        alignItems: 'center',
        // backgroundColor: 'red'
    },

    toastBody: {
        width: px2dp(300),
        minHeight: px2dp(200),
        backgroundColor: '#fff',
        borderRadius: px2dp(8),
        // elevation: 10,
        justifyContent: 'space-between',
        alignItems: 'center',
        paddingVertical: px2dp(12)
    },

    dialogHeader: {
        width: px2dp(268),
        height: px2dp(32),
        borderBottomWidth: 1,
        borderBottomColor: '#909399',
        flexDirection: 'row',
        justifyContent: 'center',
        alignItems: 'center',
        paddingHorizontal: px2dp(2)
    },

    dialogHeaderRight: {
        flexDirection: 'row',
        justifyContent: 'flex-end',
        alignItems: 'center'
    },

    footer: {
        width: px2dp(272),
        flexDirection: 'row',
        justifyContent: 'space-between',
        alignItems: 'center',
        marginTop: px2dp(24)
    },

    footerLeftBtn: {
        width: px2dp(133),
        height: px2dp(36),
        borderRadius: px2dp(18),
        justifyContent: 'center',
        alignItems: 'center',
        backgroundColor: '#00D38F58',
        borderTopRightRadius: px2dp(3),
        borderBottomRightRadius: px2dp(3),
    },

    footerRightBtn: {
        width: px2dp(133),
        height: px2dp(36),
        borderRadius: px2dp(18),
        flexDirection: 'row',
        justifyContent: 'center',
        alignItems: 'center',
        backgroundColor: colors.themeColor,
        borderTopLeftRadius: px2dp(3),
        borderBottomLeftRadius: px2dp(3)
    },

    selectItem: {
        flexDirection: 'row',
        justifyContent: 'flex-start',
        alignItems: 'center',
        borderBottomWidth: 1,
        borderBottomColor: '#303133',
        paddingTop: px2dp(16)
    },

    selectItemName: {
        fontSize: 16,
        color: '#303133',
        marginLeft: px2dp(3)
    },

    group: {
        width: px2dp(268),
        backgroundColor: '#f2f5f8',
        borderRadius: px2dp(3),
        marginTop: px2dp(12),
        paddingVertical: px2dp(6),
        justifyContent: 'flex-start',
        alignItems: 'center'
    },

    groupRow: {
        width: '100%',
        flexDirection: 'row',
        justifyContent: 'space-between',
        alignItems: 'center',
        marginBottom: px2dp(8)
    },

    groupTitle: {
        fontSize: 15,
        color: '#303133',
        marginBottom: px2dp(5)
    },

    groupHeader: {

    },

    item: {
        height: px2dp(42),
        flex: 1,
        // backgroundColor: 'red'
    },

    itemTitle: {
        fontSize: 14,
        color: '#303133'
    },

    itemInput: {
        width: '100%',
        height: px2dp(24),
        lineHeight: px2dp(24),
        justifyContent: 'center',
        alignItems: 'center'
    }
})

export default AddSampleSquareResearchDialog;