import React from 'react';
import {
    SafeAreaView,
    ScrollView,
    StatusBar,
    StyleSheet,
    Text,
    Image,
    TouchableOpacity,
    View,
    DeviceEventEmitter
} from 'react-native';
import FastImage from 'react-native-fast-image';
import { TextInput } from 'react-native-gesture-handler';
import Animated, { useAnimatedStyle, useSharedValue, withSpring, withTiming } from 'react-native-reanimated';
import { BjInstanceActualMeasurementResearchTableRow, BjInstanceSampleSquareResearch } from '../../database/Instance';
import { colors, deepCopy, handleDismissKeyboard, isEmpty, onePx, px2dp, toastShort } from '../../utils';
import { BjTypeActualMeasurementResearchTableRow, BjTypeSampleSquareResearch } from '../../utils/types';
import KitCheckBox from '../kits/KitCheckBox';
import NormalActionSheet from './../kits/NormalActionSheet';

interface Props {
}

interface State {
    tempResearchInstance: BjTypeSampleSquareResearch
}


interface TypeResearch {
    name: string
    type: string
}

const MainSampleSizeSettingDialog = (props: Props) => {
    const containerRef = React.useRef(null);
    const delayTimer = React.useRef(null);
    const delayTimer1 = React.useRef(null);
    const overlayOpacity = useSharedValue(0.1);
    const layoutScaleValue = useSharedValue(0);
    const [tempResearchInstance, setTempResearchInstance] = React.useState<BjTypeSampleSquareResearch>(deepCopy(BjInstanceSampleSquareResearch));
    const showToastListener = React.useRef(null);
    const hideToastListener = React.useRef(null);
    const tempKey = React.useRef(null);
    const tempPropName = React.useRef(null);
    const actionSheetRef = React.useRef(null);

    React.useEffect(() => {
        overlayOpacity.value = withTiming(0.2);
        layoutScaleValue.value = withSpring(0.6);
        showToastListener.current = DeviceEventEmitter.addListener('show-main-sample-size-setting-dialog', (a) => {
            setTempResearchInstance(deepCopy(a.tempResearchInstance));
            delayTimer.current = setTimeout(() => {
                handleShowToast()
            }, 0);
        });
        hideToastListener.current = DeviceEventEmitter.addListener('hide-main-sample-size-setting-dialog', (a) => {
            handleHideToast()
        });
        return () => {
            delayTimer.current && clearTimeout(delayTimer.current);
            delayTimer1.current && clearTimeout(delayTimer1.current);
            showToastListener.current && showToastListener.current?.remove();
            hideToastListener.current && hideToastListener.current?.remove();
        }
    }, []);

    const handleShowToast = () => {
        requestAnimationFrame(() => {
            containerRef.current.setNativeProps({
                style: {
                    width: '100%',
                    height: '100%'
                }
            })
            delayTimer1.current = setTimeout(() => {
                overlayOpacity.value = 0.52;
                layoutScaleValue.value = 1;
            }, 0);
        })
    };

    const handleHideToast = () => {
        delayTimer.current = setTimeout(() => {
            containerRef.current.setNativeProps({
                style: {
                    width: 0,
                    height: 0
                }
            })
        }, 240);
        overlayOpacity.value = 0.1;
        layoutScaleValue.value = 0;
        handleDismissKeyboard();
    }

    const handleComfirmToast = () => {
        DeviceEventEmitter.emit('on-main-sample-size-setting-dialog-finish', {
            key: tempKey.current,
            tempResearchInstance: tempResearchInstance
        })
        handleHideToast();
    }


    const overlayAnimatedStyle = useAnimatedStyle(() => {
        return {
            opacity: withTiming(overlayOpacity.value, { duration: 240 })
        }
    });

    const toastBodyAnimatedStyle = useAnimatedStyle(() => {
        return {
            transform: [
                {
                    scale: withSpring(layoutScaleValue.value, { stiffness: 96 }),
                }
            ],
            opacity: withTiming(layoutScaleValue.value, { duration: 120 }),
        }
    })

    const _onTextChange = (propName, text) => {
        let _tempResearchInstance = tempResearchInstance;
        let testText = text.replace(/[^\d^\.]+/g, '');
        let arr1 = testText.split('.');
        if (arr1.length > 2) {
            return toastShort("只能输入一个小数点");
        } else {
            if (arr1[1] && arr1[1].length > 2) {
                return toastShort("只能输入一个小数点后两位数");
            }
        }
        _tempResearchInstance[propName] = testText;
        let _numberOfPlants = 0;
        if (!isEmpty(_tempResearchInstance.sampleSquareWidth)) {
            _numberOfPlants += Number(_tempResearchInstance.sampleSquareWidth)
        }
        setTempResearchInstance(deepCopy(_tempResearchInstance))
    };

    const _setMainSampleSizeSettingType = (type) => {
        let _tempResearchInstance = deepCopy(tempResearchInstance);
        _tempResearchInstance.mainSampleSizeSettingType = type;
        console.log("_tempResearchInstance", _tempResearchInstance)
        setTempResearchInstance(_tempResearchInstance);
    };

    return (
        <View
            ref={containerRef}
            style={styles.container}
        >
            <View style={styles.content}>
                <Animated.View style={[styles.toastBody, toastBodyAnimatedStyle]}>
                    <View style={styles.dialogHeader}>
                        <Text style={{ fontSize: 15 }}>主样方(圆)大小设置</Text>
                    </View>
                    <View style={[styles.group, { marginTop: px2dp(18) }]}>
                        <View style={styles.groupLeft}>
                            <KitCheckBox
                                type={'radio'}
                                containerStyle={{ width: px2dp(32), height: px2dp(32) }}
                                checked={tempResearchInstance.mainSampleSizeSettingType == 'sample-square' ? true : false}
                                onChange={() => _setMainSampleSizeSettingType('sample-square')}
                            />
                            <Text style={styles.groupName}>样方:</Text>
                        </View>
                        <View style={styles.groupLeft}>
                            <TextInput
                                placeholder={"样方长"}
                                style={styles.input}
                                keyboardType={'numeric'}
                                maxLength={8}
                                enabled={tempResearchInstance.mainSampleSizeSettingType == 'sample-square'}
                                focusable={tempResearchInstance.mainSampleSizeSettingType == 'sample-square'}
                                value={tempResearchInstance.sampleSquareLong}
                                onChangeText={(text) => _onTextChange('sampleSquareLong', text)}
                            />
                            <Text style={{ fontSize: 15, color: '#7f7f7f' }}>m X </Text>
                            <TextInput
                                placeholder={"样方长"}
                                style={styles.input}
                                keyboardType={'numeric'}
                                maxLength={8}
                                enabled={tempResearchInstance.mainSampleSizeSettingType == 'sample-square'}
                                focusable={tempResearchInstance.mainSampleSizeSettingType == 'sample-square'}
                                value={tempResearchInstance.sampleSquareWidth}
                                onChangeText={(text) => _onTextChange('sampleSquareWidth', text)}
                            />
                            <Text style={{ fontSize: 15, color: '#7f7f7f' }}>m</Text>
                        </View>
                    </View>
                    <View style={styles.group}>
                        <View style={styles.groupLeft}>
                            <KitCheckBox
                                type={'radio'}
                                containerStyle={{ width: px2dp(32), height: px2dp(32) }}
                                checked={tempResearchInstance.mainSampleSizeSettingType == 'sample-round' ? true : false}
                                onChange={() => _setMainSampleSizeSettingType('sample-round')}
                            />
                            <Text style={styles.groupName}>样圆:</Text>
                        </View>
                        <View style={styles.groupLeft}>
                            <TextInput
                                placeholder={"半径"}
                                style={styles.input}
                                keyboardType={'numeric'}
                                maxLength={8}
                                enabled={tempResearchInstance.mainSampleSizeSettingType == 'sample-round'}
                                focusable={tempResearchInstance.mainSampleSizeSettingType == 'sample-round'}
                                value={tempResearchInstance.sampleRoundRadius}
                                onChangeText={(text) => _onTextChange('sampleRoundRadius', text)}
                            />
                            <Text style={{ fontSize: 15, color: '#7f7f7f' }}>m</Text>
                        </View>
                    </View>
                    <View style={styles.footer}>
                        <TouchableOpacity
                            onPress={handleHideToast}
                            style={styles.footerLeftBtn}
                        >
                            <Text style={{ fontSize: 14, color: colors.greenTextColor }}>取消</Text>
                        </TouchableOpacity>
                        <TouchableOpacity
                            onPress={handleComfirmToast}
                            style={styles.footerRightBtn}
                        >
                            <Text style={{ fontSize: 14, color: '#fff' }}>确定</Text>
                        </TouchableOpacity>
                    </View>
                </Animated.View>
                <Animated.View style={[styles.overlay, overlayAnimatedStyle]}>
                </Animated.View>
            </View>
        </View>

    )
};

const styles = StyleSheet.create({
    overlay: {
        position: 'absolute',
        top: 0,
        bottom: 0,
        left: 0,
        right: 0,
        width: '100%',
        height: '100%',
        backgroundColor: '#000',
        zIndex: -1
    },

    container: {
        position: 'absolute',
        top: 0,
        bottom: 0,
        left: 0,
        right: 0,
        zIndex: 999,
        width: 0,
        height: 0,
        overflow: 'hidden'
    },

    content: {
        position: 'relative',
        width: '100%',
        height: '100%',
        flex: 1,
        justifyContent: 'center',
        alignItems: 'center',
        // backgroundColor: 'red'
    },

    toastBody: {
        width: px2dp(300),
        minHeight: px2dp(200),
        backgroundColor: '#fff',
        borderRadius: px2dp(8),
        elevation: 12,
        justifyContent: 'space-between',
        alignItems: 'center',
        paddingVertical: px2dp(12)
    },

    dialogHeader: {
        width: px2dp(268),
        height: px2dp(32),
        borderBottomWidth: 1,
        borderBottomColor: '#909399',
        flexDirection: 'row',
        justifyContent: 'center',
        alignItems: 'center',
        paddingHorizontal: px2dp(2)
    },

    dialogHeaderRight: {
        flexDirection: 'row',
        justifyContent: 'flex-end',
        alignItems: 'center'
    },

    footer: {
        width: px2dp(272),
        flexDirection: 'row',
        justifyContent: 'space-between',
        alignItems: 'center',
        marginTop: px2dp(24)
    },

    footerLeftBtn: {
        width: px2dp(133),
        height: px2dp(36),
        borderRadius: px2dp(18),
        justifyContent: 'center',
        alignItems: 'center',
        backgroundColor: '#00D38F58',
        borderTopRightRadius: px2dp(3),
        borderBottomRightRadius: px2dp(3),
    },

    footerRightBtn: {
        width: px2dp(133),
        height: px2dp(36),
        borderRadius: px2dp(18),
        justifyContent: 'center',
        alignItems: 'center',
        backgroundColor: colors.themeColor,
        borderTopLeftRadius: px2dp(3),
        borderBottomLeftRadius: px2dp(3)
    },

    selectItem: {
        flexDirection: 'row',
        justifyContent: 'flex-start',
        alignItems: 'center',
        borderBottomWidth: 1,
        borderBottomColor: '#303133',
        paddingTop: px2dp(16)
    },

    selectItemName: {
        fontSize: 16,
        color: '#303133',
        marginLeft: px2dp(3)
    },

    group: {
        width: px2dp(268),
        borderRadius: px2dp(3),
        marginTop: px2dp(12),
        paddingVertical: px2dp(6),
        flexDirection: 'row',
        justifyContent: 'flex-start',
        alignItems: 'center'
    },

    groupName: {
        fontSize: 15,
        color: '#555'
    },

    groupLeft: {
        flexDirection: 'row',
        justifyContent: 'flex-start',
        alignItems: 'center',
        marginRight: px2dp(8)
    },

    input: {
        width: px2dp(64),
        height: px2dp(32),
        justifyContent: 'center',
        alignItems: 'center',
        borderWidth: 1,
        borderColor: '#d0d0d0',
        borderRadius: px2dp(3),
        paddingLeft: px2dp(5),
        marginRight: px2dp(3)
    },

    groupTitle: {
        fontSize: 15,
        color: '#303133',
        marginBottom: px2dp(5)
    },

    groupHeader: {

    },

    item: {
        height: px2dp(42),
        flex: 1,
        // backgroundColor: 'red'
    },

    itemTitle: {
        fontSize: 14,
        color: '#303133'
    },

    itemInput: {
        width: '100%',
        height: px2dp(24),
        lineHeight: px2dp(24),
        justifyContent: 'center',
        alignItems: 'center'
    }
})

export default MainSampleSizeSettingDialog;