import React from 'react';
import {
    SafeAreaView,
    ScrollView,
    StatusBar,
    StyleSheet,
    Text,
    Image,
    TouchableOpacity,
    View,
    DeviceEventEmitter
} from 'react-native';
import FastImage from 'react-native-fast-image';
import { TextInput } from 'react-native-gesture-handler';
import Animated, { useAnimatedStyle, useSharedValue, withSpring, withTiming } from 'react-native-reanimated';
import { BjInstanceActualMeasurementResearchTableRow } from '../../database/Instance';
import { colors, deepCopy, handleDismissKeyboard, isEmpty, onePx, px2dp, toastShort } from '../../utils';
import { BjTypeActualMeasurementResearchTableRow, BjTypeSheetOption } from '../../utils/types';

interface Props {
}

interface State {
    row: BjTypeActualMeasurementResearchTableRow
}


interface TypeResearch {
    name: string
    type: string
}

const MutipleSelectDialog = () => {
    const containerRef = React.useRef(null);
    const delayTimer = React.useRef(null);
    const delayTimer1 = React.useRef(null);
    const overlayOpacity = useSharedValue(0.1);
    const layoutScaleValue = useSharedValue(1);
    // const [tempRow, setTempRow] = React.useState<BjTypeActualMeasurementResearchTableRow>(deepCopy(BjInstanceActualMeasurementRe,searchTableRow));
    const [sheetList, setSheetList] = React.useState<Array<BjTypeSheetOption>>([]);
    const [extraValue, setExtraValue] = React.useState("");
    const [title, setTitle] = React.useState<string>("");
    const [useExtra, setUseExtra] = React.useState(true);
    const showToastListener = React.useRef(null);
    const hideToastListener = React.useRef(null);
    const tempKey = React.useRef(null);

    React.useEffect(() => {
        overlayOpacity.value = withTiming(0.2);
        layoutScaleValue.value = withSpring(0);
        showToastListener.current = DeviceEventEmitter.addListener('show-custom-sheet-dialog', (a) => {
            const {
                optionList,
                mutipleDialogTitle,
                includeExtra = false,
                key,
                value = ""
            } = a;
            console.log("split", value)
            let list = deepCopy(optionList);
            tempKey.current = key;
            let extraValue = "";
            let valueList = value.split(',');
            list.forEach(ele => {
                if (valueList.includes(ele.name)) {
                    ele.checked = true
                }
            })
            if (!extraValue) {
                valueList.forEach(valueStr => {
                    const findValueName = list.find(ele => {
                        return ele.name == valueStr;
                    })
                    if (!findValueName) {
                        extraValue = valueStr;
                    }
                })
            }
            setSheetList(list);
            setTitle(mutipleDialogTitle);
            setUseExtra(includeExtra);
            setExtraValue(extraValue);
            delayTimer.current = setTimeout(() => {
                handleShowToast()
            }, 0);
        });
        hideToastListener.current = DeviceEventEmitter.addListener('hide-custom-sheet-dialog', (a) => {
            handleHideToast()
        });
        return () => {
            delayTimer.current && clearTimeout(delayTimer.current);
            delayTimer1.current && clearTimeout(delayTimer1.current);
            showToastListener.current && showToastListener.current?.remove();
            hideToastListener.current && hideToastListener.current?.remove();
        }
    }, []);

    const handleShowToast = () => {
        requestAnimationFrame(() => {
            containerRef.current.setNativeProps({
                style: {
                    width: '100%',
                    height: '100%'
                }
            })
            delayTimer1.current = setTimeout(() => {
                overlayOpacity.value = 0.52;
                layoutScaleValue.value = 1;
            }, 0);
        })
    };

    const handleHideToast = () => {
        delayTimer.current = setTimeout(() => {
            containerRef.current.setNativeProps({
                style: {
                    width: 0,
                    height: 0
                }
            })
        }, 240);
        overlayOpacity.value = 0.1;
        layoutScaleValue.value = 0;
        handleDismissKeyboard();
    }

    const handleComfirmToast = () => {
        const selectedList = [];
        sheetList.forEach(option => {
            if (option.checked) {
                selectedList.push(option.name);
            }
        });
        if (!isEmpty(extraValue)) {
            selectedList.push(extraValue);
        }
        let selectedStr = selectedList.toString();
        DeviceEventEmitter.emit('on-mutiple-select-dialog-finish', {
            key: tempKey.current,
            selectedStr,
        })
        handleHideToast();
    }


    const overlayAnimatedStyle = useAnimatedStyle(() => {
        return {
            opacity: withTiming(overlayOpacity.value, { duration: 240 })
        }
    });

    const toastBodyAnimatedStyle = useAnimatedStyle(() => {
        return {
            transform: [
                {
                    scale: withSpring(layoutScaleValue.value, { stiffness: 96 }),
                }
            ],
            opacity: withTiming(layoutScaleValue.value, { duration: 120 }),
        }
    })

    const _onTextChange = (propName, text) => {
        // let _tempRow = tempRow;
        let testText = text.replace(/[^\d^\.]+/g, '');
        let arr1 = testText.split('.');
        if (arr1.length > 2) {
            return toastShort("只能输入一个小数点");
        } else {
            if (arr1[1] && arr1[1].length > 2) {
                return toastShort("只能输入一个小数点后两位数");
            }
        }
    };

    const switchChecked = (item, index) => {
        let list = sheetList;
        list[index].checked = !item.checked;
        setSheetList(deepCopy(list));
    };

    return (
        <View
            ref={containerRef}
            style={styles.container}
        >
            <View style={styles.content}>
                <Animated.View style={[styles.toastBody, toastBodyAnimatedStyle]}>
                    <View style={styles.dialogHeader}>
                        <Text style={{ fontSize: 15 }}>{`请选择${title} (多选)`}</Text>
                    </View>
                    <View style={styles.group}>
                        {
                            sheetList && sheetList.map((item, index) => {
                                return (
                                    <TouchableOpacity
                                        onPress={() => switchChecked(item, index)}
                                        style={[
                                            item.checked ?
                                                styles.checkedBtn
                                                :
                                                styles.btn
                                        ]}>
                                        <Text style={[
                                            styles.btnText,
                                            !item.checked ?
                                                { color: colors.blackColor }
                                                :
                                                null
                                        ]}>{item.name}</Text>
                                    </TouchableOpacity>
                                )
                            })
                        }
                    </View>
                    {
                        useExtra ?
                            <View style={styles.extraLine}>
                                <Text style={{ fontSize: 14, color: '#666' }}>其他：</Text>
                                <TextInput
                                    value={extraValue}
                                    placeholder={'不超过10个字'}
                                    onChangeText={(text) => setExtraValue(text)}
                                    maxLength={10}
                                    style={styles.extraInput}
                                />
                            </View>
                            :
                            null
                    }
                    <View style={styles.footer}>
                        <TouchableOpacity
                            onPress={handleHideToast}
                            style={styles.footerLeftBtn}
                        >
                            <Text style={{ fontSize: 14, color: colors.greenTextColor }}>取消</Text>
                        </TouchableOpacity>
                        <TouchableOpacity
                            onPress={handleComfirmToast}
                            style={styles.footerRightBtn}
                        >
                            <Text style={{ fontSize: 14, color: '#fff' }}>确定</Text>
                        </TouchableOpacity>
                    </View>
                </Animated.View>
                <Animated.View style={[styles.overlay, overlayAnimatedStyle]}>
                </Animated.View>
            </View>
        </View>

    )
};

const styles = StyleSheet.create({
    overlay: {
        position: 'absolute',
        top: 0,
        bottom: 0,
        left: 0,
        right: 0,
        width: '100%',
        height: '100%',
        backgroundColor: '#000',
        zIndex: -1
    },

    container: {
        position: 'absolute',
        top: 0,
        bottom: 0,
        left: 0,
        right: 0,
        zIndex: 999,
        width: 0,
        height: 0,
        overflow: 'hidden'
    },

    content: {
        position: 'relative',
        width: '100%',
        height: '100%',
        flex: 1,
        justifyContent: 'center',
        alignItems: 'center',
        // backgroundColor: 'red'
    },

    toastBody: {
        width: px2dp(300),
        minHeight: px2dp(200),
        backgroundColor: '#f2f6f8',
        borderRadius: px2dp(8),
        elevation: 12,
        justifyContent: 'space-between',
        alignItems: 'center',
        paddingVertical: px2dp(12)
    },

    dialogHeader: {
        width: px2dp(268),
        height: px2dp(32),
        borderBottomWidth: 1,
        borderBottomColor: '#909399',
        flexDirection: 'row',
        justifyContent: 'center',
        alignItems: 'center',
        paddingHorizontal: px2dp(2)
    },

    dialogHeaderRight: {
        flexDirection: 'row',
        justifyContent: 'flex-end',
        alignItems: 'center'
    },

    footer: {
        width: px2dp(272),
        flexDirection: 'row',
        justifyContent: 'space-between',
        alignItems: 'center',
        marginTop: px2dp(24)
    },

    footerLeftBtn: {
        width: px2dp(133),
        height: px2dp(36),
        borderRadius: px2dp(18),
        justifyContent: 'center',
        alignItems: 'center',
        backgroundColor: '#00D38F58',
        borderTopRightRadius: px2dp(3),
        borderBottomRightRadius: px2dp(3),
    },

    footerRightBtn: {
        width: px2dp(133),
        height: px2dp(36),
        borderRadius: px2dp(18),
        justifyContent: 'center',
        alignItems: 'center',
        backgroundColor: colors.themeColor,
        borderTopLeftRadius: px2dp(3),
        borderBottomLeftRadius: px2dp(3)
    },

    selectItem: {
        flexDirection: 'row',
        justifyContent: 'flex-start',
        alignItems: 'center',
        borderBottomWidth: 1,
        borderBottomColor: '#303133',
        paddingTop: px2dp(16)
    },

    selectItemName: {
        fontSize: 16,
        color: '#303133',
        marginLeft: px2dp(3)
    },

    group: {
        width: px2dp(268),
        flexDirection: 'row',
        justifyContent: 'flex-start',
        alignItems: 'flex-start',
        marginTop: px2dp(12),
        paddingVertical: px2dp(6),
        flexWrap: 'wrap'
    },

    groupRow: {
        width: '100%',
        flexDirection: 'row',
        justifyContent: 'space-between',
        alignItems: 'center',
        marginBottom: px2dp(8)
    },

    groupTitle: {
        fontSize: 15,
        color: '#303133',
        marginBottom: px2dp(5)
    },

    groupHeader: {

    },

    item: {
        height: px2dp(42),
        flex: 1,
        // backgroundColor: 'red'
    },

    itemTitle: {
        fontSize: 14,
        color: '#303133'
    },

    itemInput: {
        width: '100%',
        height: px2dp(24),
        lineHeight: px2dp(24),
        justifyContent: 'center',
        alignItems: 'center'
    },

    btn: {
        minWidth: px2dp(72),
        paddingHorizontal: px2dp(8),
        height: px2dp(32),
        backgroundColor: '#fff',
        justifyContent: 'center',
        alignItems: 'center',
        borderRadius: px2dp(4),
        marginRight: px2dp(10),
        marginBottom: px2dp(10),
        borderWidth: 1,
        borderColor: '#d2d2d2'
    },

    checkedBtn: {
        minWidth: px2dp(72),
        paddingHorizontal: px2dp(8),
        height: px2dp(32),
        backgroundColor: colors.themeColor,
        borderWidth: 1,
        borderColor: colors.themeColor,
        justifyContent: 'center',
        alignItems: 'center',
        borderRadius: px2dp(4),
        marginRight: px2dp(10),
        marginBottom: px2dp(10),
    },

    btnText: {
        fontSize: 14,
        color: '#fff'
    },

    extraLine: {
        width: px2dp(260),
        flexDirection: 'row',
        justifyContent: 'flex-start',
        alignItems: 'center',
        marginBottom: px2dp(12),
        paddingHorizontal: px2dp(4)
    },

    extraInput: {
        width: px2dp(160),
        height: px2dp(28),
        borderBottomColor: '#a1a1a1',
        borderBottomWidth: onePx
    }
})

export default MutipleSelectDialog;