import React from 'react';
import {
    SafeAreaView,
    ScrollView,
    StatusBar,
    StyleSheet,
    Text,
    Image,
    TouchableOpacity,
    View,
    DeviceEventEmitter
} from 'react-native';
import { navigate } from '../../NavigationService';
import API from '../../api';
import { isEmpty, myConfirm, px2dp, size, toastShort, validResponseCode } from '../../utils';
import Store from '../../utils/Store';
import { BjTypeCommonResearch, BjTypeResearchConnection, BjTypeResearchNameDict } from '../../utils/types';

interface Props {
}

interface State {
    researchList: Array<BjTypeCommonResearch>
    currentPageName: string
}

export default class FloatFastWindow extends React.Component<Props, State> {
    constructor(props: Props) {
        super(props);
    };

    public tempIndex = 0;
    public addResearchItemListener = null;
    public deleteResearchItemListener = null;
    public synchronizateCurrentPageListener = null;

    public readonly state: Readonly<State> = {
        researchList: [],
        currentPageName: "",
    };

    componentDidMount() {
        Store.getJsonObject('float-window-data')
            .then(res => {
                console.log("存储数据是", res);
                this.setState({ researchList: JSON.parse(res) })
            })
            .catch(err => {
                console.log("测试eeee", err)
            })
        this.addResearchItemListener = DeviceEventEmitter.addListener('add-common-research-float', (a) => {
            const {
                researchItem
            } = a;
            console.log("researchItem", researchItem)
            let { researchList } = this.state;
            if (researchList.length < 3) {
                const find = researchList.find(ele => {
                    return ele.id === researchItem.id;
                });
                if (!find) {
                    researchList.push(researchItem);
                    this.setState({ researchList });
                    Store.saveJsonObject('float-window-data', JSON.stringify(researchList))
                }
            }
        });
        this.deleteResearchItemListener = DeviceEventEmitter.addListener('delete-research-item', (a) => {
            const {
                researchItem
            } = a;
            console.log("researchItem", researchItem)
            let { researchList } = this.state;
            let findIndex = -1;
            researchList.forEach((ele, index) => {
                if (ele.id == researchItem.id) {
                    findIndex = index;
                }
            })
            if (findIndex > -1) {
                researchList.splice(findIndex, 1);
                this.setState({ researchList });
                Store.saveJsonObject('float-window-data', JSON.stringify(researchList))
            }
        })
        this.synchronizateCurrentPageListener = DeviceEventEmitter.addListener('synchronizateCurrentPage', (a) => {
            console.log("监听到当前页面", a.pageName);
            this.setState({ currentPageName: a.pageName });
        })
    }

    componentWillUnmount(): void {
        this.addResearchItemListener && this.addResearchItemListener?.remove();
        this.deleteResearchItemListener && this.deleteResearchItemListener?.remove();
        this.synchronizateCurrentPageListener && this.synchronizateCurrentPageListener?.remove();
    }

    adaptItemIcon(research: BjTypeCommonResearch) {
        switch (research.type) {
            case 'actualMeasurementResearch':
                return (
                    <Image
                        source={require('./../../assets/icons/research-icon-2.png')}
                        style={styles.itemIcon}
                    />
                )
                break;
            case 'sampleLineResearch':
                return (
                    <Image
                        source={require('./../../assets/icons/research-icon-4.png')}
                        style={styles.itemIcon}
                    />
                )
                break;
            case 'sampleSquareResearch':
                return (
                    <Image
                        source={require('./../../assets/icons/research-icon-3.png')}
                        style={styles.itemIcon}
                    />
                )
                break;
            default:
                return null
                break;
        }
    }

    deleteResearchItem(index) {
        this.tempIndex = index;
        myConfirm({
            title: "移除悬浮窗不会删除数据",
            confirmFun: this.comfirmToDelete.bind(this),
            confirmText: "确定"
        })
    }

    comfirmToDelete() {
        let { researchList } = this.state;
        researchList.splice(this.tempIndex, 1);
        this.setState({ researchList });
        Store.saveJsonObject('float-window-data', JSON.stringify(researchList))
    }

    async jumpToTable(item) {
        try {
            let requestMethod = null;
            let tablePageRouterName = '';
            let queryResearchConnectionParams: BjTypeResearchConnection = {
            };
            let researchType = item.type;
            switch (item.type) {
                // case 'communityProfileResearch':
                //     requestMethod = API.getCommunityProfileResearchDetailstV1;
                //     tablePageRouterName = 'ResearchCommonTablePage';
                //     queryResearchConnectionParams.communityProfileResearchId = item.researchId;
                //     break;
                case 'actualMeasurementResearch':
                    requestMethod = API.getActualMeasurementResearchDetailstV1;
                    tablePageRouterName = 'ResearchCommonTablePage';
                    queryResearchConnectionParams.actualMeasurementResearchId = item.researchId;
                    break;
                case 'sampleSquareResearch':
                    requestMethod = API.getSampleSquareResearchDetailstV1;
                    tablePageRouterName = 'ResearchCommonTablePage';
                    queryResearchConnectionParams.sampleSquareResearchId = item.researchId;
                    break;
                case 'sampleLineResearch':
                    requestMethod = API.getSampleLineResearchDetailstV1;
                    tablePageRouterName = 'ResearchCommonTablePage';
                    queryResearchConnectionParams.sampleLineResearchId = item.researchId;
                    break;
                default:
                    break;
            }
            let queryResearchConnectionTask = API.queryResearchConnection(queryResearchConnectionParams);
            console.log("queryResearchConnectionTask", JSON.stringify(queryResearchConnectionTask))
            // return false;
            if (!requestMethod) {
                return toastShort("请检查接口映射")
            }
            Promise.all([
                queryResearchConnectionTask,
                requestMethod({
                    id: item.researchId
                })
            ])
                .then(resList => {
                    console.log("这是首页调查详情", resList)
                    const researchConnectionRes = resList[0];
                    console.log("researchConnectionRes", JSON.stringify(researchConnectionRes))
                    const researchDetailsRes = resList[1];
                    if (validResponseCode(researchDetailsRes) && validResponseCode(researchConnectionRes)) {
                        let routeParams = {
                            researchInstance: researchDetailsRes.data.list ? researchDetailsRes.data.list[0] : researchDetailsRes.data.info,
                            researchType: researchType,
                            justView: false
                        }
                        if (researchConnectionRes.data.list.length) {
                            //@ts-ignore
                            routeParams.researchConnection = researchConnectionRes.data.list[0];
                        } else {
                            return toastShort(
                                item.type == 'communityProfileResearch' ?
                                    "当前群落概况信息没有关联调查"
                                    :
                                    "请先填写群落概况信息"
                            )
                        }
                        if (item.type == 'communityProfileResearch') {
                            let connectResearchType: BjTypeResearchNameDict = "actualMeasurementResearch";
                            let connectResearchId = null;
                            let quereConnectResearchDetailsMethod = null;
                            let researchConnection: BjTypeResearchConnection = researchConnectionRes.data.list[0];
                            if (!isEmpty(researchConnection.actualMeasurementResearchId)) {
                                connectResearchType = 'actualMeasurementResearch';
                                connectResearchId = researchConnection['actualMeasurementResearchId'];
                                quereConnectResearchDetailsMethod = API.getActualMeasurementResearchDetailstV1;
                            } else if (!isEmpty(researchConnection.sampleLineResearchId)) {
                                connectResearchType = 'sampleLineResearch';
                                connectResearchId = researchConnection['sampleLineResearchId'];
                                quereConnectResearchDetailsMethod = API.getSampleLineResearchDetailstV1;
                            } else if (!isEmpty(researchConnection.sampleSquareResearchId)) {
                                connectResearchType = 'sampleSquareResearch';
                                connectResearchId = researchConnection['sampleSquareResearchId'];
                                quereConnectResearchDetailsMethod = API.getSampleSquareResearchDetailstV1;
                            }
                            if (connectResearchType && connectResearchId) {
                                console.log("routeParams------>", routeParams)
                                quereConnectResearchDetailsMethod && quereConnectResearchDetailsMethod({ id: connectResearchId })
                                    .then(res => {
                                        routeParams.researchInstance = res.data.list[0];
                                        // routeParams.researchType = item.type;
                                        navigate(tablePageRouterName, routeParams)
                                    })
                                    .catch(err => {
                                    })
                            }
                        } else {
                            console.log("routeParams------>", routeParams)
                            DeviceEventEmitter.emit('add-common-research-float', { researchItem: item })
                            navigate(tablePageRouterName, routeParams)
                        }
                    } else {
                        toastShort("跳转失败，请稍后重试");
                    }
                })
                .catch(err => {
                    toastShort("获取详情失败" + err)
                    console.log("err", err)
                })
        } catch (e) {
            toastShort("获取详情失败" + e)
        }
    }

    render() {
        const { researchList, currentPageName } = this.state;
        if ([
            "NewActualMeasurementResearch",
            "NewCommunityProfileResearch",
            "NewSampleLineResearch",
            "NewSampleSquareResearch",
            "ResearchCommonTablePage",
            "ResearchCommonSmallSeedlingTable",
            "ResearchCommonSmallTreeTable",
            "ResearchCommonFrequencyPage",
            "GeoPicker",
            "PureCamera",
            "Login",
            "SearchSpeciesName",
            "ImagePreviewPage",
        ].includes(currentPageName)) {
            return <></>
        }
        return (
            <View style={styles.container}>
                {
                    researchList && researchList.map((research, index) => {
                        return (
                            <View
                                style={styles.item}
                                key={index + ''}
                            >
                                <TouchableOpacity
                                    style={styles.itemContent}
                                    onPress={() => this.jumpToTable(research)}
                                >
                                    {this.adaptItemIcon(research)}
                                    <Text style={styles.itemName}>{research.serialNumberAndCode}</Text>
                                </TouchableOpacity>
                                <TouchableOpacity
                                    style={styles.closeBtn}
                                    onPress={() => this.deleteResearchItem(index)}
                                >
                                    <Image
                                        source={require('./../../assets/icons/close-icon.png')}
                                        style={styles.closeIcon}
                                    />
                                </TouchableOpacity>
                            </View>
                        )
                    })
                }
            </View>
        )
    }
}


const styles = StyleSheet.create({
    container: {
        position: 'absolute',
        right: 0,
        bottom: px2dp(180),
        width: px2dp(48),
        flexDirection: 'column',
        justifyContent: 'flex-start',
        alignItems: 'center',
        paddingVertical: px2dp(8)
    },

    item: {
        width: px2dp(48),
        height: px2dp(86),
        justifyContent: 'center',
        alignItems: 'center',
        marginTop: px2dp(12),

        backgroundColor: '#fff',
        elevation: 8,
        borderTopLeftRadius: px2dp(12),
        borderBottomLeftRadius: px2dp(12),
    },

    itemContent: {
        width: px2dp(42),
        height: px2dp(60),
        justifyContent: 'center',
        alignItems: 'center',
        borderBottomWidth: 1,
        borderBottomColor: '#eee',
    },

    itemIcon: {
        width: px2dp(24),
        height: px2dp(24),
    },

    itemName: {
        textAlign: 'center',
        fontSize: 12
    },

    closeBtn: {
        width: '100%',
        height: px2dp(26),
        justifyContent: 'center',
        alignItems: 'center'
    },

    closeIcon: {
        width: px2dp(14),
        height: px2dp(14)
    }
})