import React from 'react';
import {
    SafeAreaView,
    ScrollView,
    StatusBar,
    StyleSheet,
    Text,
    Image,
    TouchableOpacity,
    View,
    DeviceEventEmitter
} from 'react-native';
import FastImage from 'react-native-fast-image';
import { colors, px2dp } from '../../utils';

interface Props {
    type?: 'single' | 'mutiple'
    onPressLeft?: Function
    onPressRight?: Function
    onPressBtn?: Function
    title?: string
    leftTitle?: string
    rightTitle?: string
    leftMarkerNumber?: number
    rightMarkerNumber?: number
    backgroundColor?: string
    btnTextColor?: string
}

interface State {
}

export default class KitFloatBottomBtn extends React.Component<Props, State> {
    constructor(props: Props) {
        super(props);
    };

    public delayTimer = null;
    public btnContainerRef = null;
    public keyboardShowListener = null;
    public keyboardHideListner = null;

    public readonly state: Readonly<State> = {
    };

    componentDidMount(): void {
        this.keyboardShowListener = DeviceEventEmitter.addListener("app_keyboard_did_show", (a) => {
            requestAnimationFrame(() => {
                this.btnContainerRef.setNativeProps({
                    style: {
                        height: px2dp(0),
                        marginVertical: px2dp(0)
                    }
                })
            })
        })
        this.keyboardHideListner = DeviceEventEmitter.addListener("app_keyboard_did_hide", (a) => {
            const { type = 'single' } = this.props;
            this.delayTimer = setTimeout(() => {
                requestAnimationFrame(() => {
                    this.btnContainerRef.setNativeProps({
                        style: {
                            height: type == 'single' ? px2dp(36) : px2dp(54),
                        }
                    })
                })
            }, 100);
        })
    }

    componentWillUnmount() {
        this.delayTimer && clearTimeout(this.delayTimer);
        this.keyboardHideListner && this.keyboardHideListner.remove();
        this.keyboardShowListener && this.keyboardShowListener.remove();
        this.setState = (state, callback) => {
            return;
        }
    }


    render() {
        const {
            type = 'single',
            onPressLeft,
            onPressRight,
            leftTitle,
            rightTitle,
            title,
            onPressBtn,
            leftMarkerNumber = 0,
            rightMarkerNumber = 0,
            backgroundColor = colors.themeColor,
            btnTextColor = '#fff'
        } = this.props;
        return (
            <>
                {
                    type == 'mutiple' ?
                        <View
                            ref={(c) => this.btnContainerRef = c}
                            style={styles.twoBtnContainer}
                        >
                            <TouchableOpacity
                                style={styles.halfBtnLeft}
                                onPress={() => onPressLeft()}
                            >
                                <View style={[styles.marker, leftMarkerNumber == 0 ? { opacity: 0 } : null]}>
                                    <Text style={styles.markerText}>{leftMarkerNumber}</Text>
                                </View>
                                <Text style={[styles.btnText, { color: '#fff' }]}>{leftTitle}</Text>
                                <View style={[styles.marker, { opacity: 0 }]}>
                                    <Text style={styles.markerText}>1</Text>
                                </View>
                            </TouchableOpacity>
                            <TouchableOpacity
                                style={styles.halfBtnRight}
                                onPress={() => onPressRight()}
                            >
                                <View style={[styles.marker, rightMarkerNumber == 0 ? { opacity: 0 } : null]}>
                                    <Text style={styles.markerText}>1</Text>
                                </View>
                                <Text style={styles.btnText}>{rightTitle}</Text>
                                <View style={[styles.marker, { opacity: 0 }]}>
                                    <Text style={styles.markerText}>1</Text>
                                </View>
                            </TouchableOpacity>
                        </View>
                        :
                        <View
                            ref={(c) => this.btnContainerRef = c}
                            style={[styles.btnContainer, { backgroundColor: backgroundColor }]}
                        >
                            <TouchableOpacity
                                onPress={() => onPressBtn()}
                                style={styles.btnContent}
                            >
                                <Text style={[styles.btnText, { color: btnTextColor }]}>{title}</Text>
                            </TouchableOpacity>
                        </View>
                }
            </>
        )
    }
}


const styles = StyleSheet.create({

    twoBtnContainer: {
        position: 'absolute',
        bottom: px2dp(0),
        left: px2dp(0),
        width: px2dp(375),
        height: px2dp(54),
        flexDirection: 'row',
        zIndex: 999,
        justifyContent: 'space-between',
        alignItems: 'center',
        overflow: 'hidden',
        paddingBottom: px2dp(18),
        paddingHorizontal: px2dp(13)
    },

    btnContainer: {
        position: 'absolute',
        bottom: px2dp(18),
        left: px2dp(13),
        width: px2dp(350),
        height: px2dp(36),
        borderRadius: px2dp(18),
        backgroundColor: colors.themeColor,
        overflow: 'hidden',
        zIndex: 999,
        elevation: 6
    },

    btnContent: {
        width: '100%',
        height: '100%',
        justifyContent: 'center',
        alignItems: 'center'
    },

    halfBtnLeft: {
        width: px2dp(172),
        height: '100%',
        backgroundColor: colors.blueColor,
        justifyContent: 'center',
        alignItems: 'center',
        borderTopLeftRadius: px2dp(18),
        borderBottomLeftRadius: px2dp(18),
        borderTopRightRadius: px2dp(3),
        borderBottomRightRadius: px2dp(3),
        elevation: 6,
        flexDirection: 'row',
        overflow: 'hidden',
    },

    halfBtnRight: {
        width: px2dp(172),
        height: '100%',
        backgroundColor: colors.themeColor,
        justifyContent: 'center',
        alignItems: 'center',
        borderTopRightRadius: px2dp(18),
        borderBottomRightRadius: px2dp(18),
        borderTopLeftRadius: px2dp(3),
        borderBottomLeftRadius: px2dp(3),
        elevation: 6
    },

    marker: {
        width: px2dp(20),
        height: px2dp(20),
        backgroundColor: colors.redColor,
        elevation: 2,
        borderWidth: 1,
        borderColor: '#fff',
        borderRadius: px2dp(10),
        justifyContent: 'center',
        alignItems: 'center',
        marginHorizontal: px2dp(3),
    },

    btnText: {
        fontSize: 15,
        color: '#fff'
    },

    markerText: {
        fontSize: 13,
        color: '#fff'
    }
})