import React from 'react';
import {
    SafeAreaView,
    ScrollView,
    StatusBar,
    StyleSheet,
    Text,
    Image,
    TouchableOpacity,
    View,
    TextInput
} from 'react-native';
import { colors, filterEmoji, onePx, px2dp } from '../../utils';

interface Props {
    theme?: 'gray' | 'black'
    rowType?: 'input' | 'text' | 'pick'
    title?: string
    isNeeded?: boolean
    value?: string
    placeholderText?: string
    rowInputType?: 'number' | 'string' | 'default'
    onPress?: Function
    onChangeText?: Function
    rowInputMaxLength?: number
    hideRightIcon?: boolean
    rightIcon?: any
    isLast?: boolean
    onInputBlur?: Function
    fontBold?: boolean
    hideTitle?: boolean
    hasPermission?: boolean,
    multipleLineText?: boolean
    renderRightIcon?: Function
    inlineLayout?: boolean
}

interface State {
}

export default class KitFormSingleRow extends React.Component<Props, State> {
    constructor(props: Props) {
        super(props);
    };

    public readonly state: Readonly<State> = {
    };

    _onChangeText(text) {
        const newText = filterEmoji(text);
        const { onChangeText } = this.props;
        onChangeText && onChangeText(newText);
    }

    render() {
        const {
            title, isNeeded, rowType, value, placeholderText,
            rowInputType, onPress, onChangeText, rowInputMaxLength = 30,
            hideRightIcon = false, rightIcon, isLast = false, theme = 'black',
            onInputBlur, fontBold = false, hideTitle = false, hasPermission = true,
            multipleLineText = false, renderRightIcon, inlineLayout = false
        } = this.props;
        return (
            <TouchableOpacity
                onPress={() => onPress && onPress()}
                disabled={!hasPermission}
                style={[
                    styles.formSingleRow,
                    isLast ? { marginBottom: 0, borderBottomWidth: 0 } : null,
                    hideTitle ? { paddingBottom: px2dp(18), paddingTop: px2dp(10) } : null,
                    inlineLayout ? styles.formGroupRowInline : null
                ]}>
                <View style={styles.formSingleRowLeft}>
                    {
                        hideTitle ?
                            null
                            :
                            <View style={styles.formGroupTitleContainer}>
                                <Text style={[styles.formRowTitle, theme == 'gray' ? { color: colors.normalBlackColor6 } : null]}>
                                    {title}
                                    {isNeeded && hasPermission && <Text style={{ color: colors.redColor }}>*</Text>}
                                </Text>
                            </View>
                    }
                    {
                        rowType == 'input' ?
                            <TextInput
                                style={[styles.formRowPlaceHolderTextInput, { fontWeight: fontBold && value ? '700' : '400' }]}
                                value={value}
                                placeholder={placeholderText}
                                editable={hasPermission}
                                keyboardType={rowInputType == 'number' ? 'numeric' : 'default'}
                                onChangeText={this._onChangeText.bind(this)}
                                maxLength={rowInputMaxLength}
                                onBlur={() => onInputBlur && onInputBlur()}
                            />
                            :
                            <>
                                {
                                    value ?
                                        <Text style={[styles.formValueText, { fontWeight: fontBold ? '700' : '400' }, !multipleLineText ? { height: px2dp(20) } : null]}>{value + ''}</Text>
                                        :
                                        <Text style={styles.formRowPlaceHolderText}>{placeholderText}</Text>
                                }
                            </>
                    }
                </View>
                {
                    renderRightIcon ?
                        <View style={styles.formSingleRowRight}>
                            {renderRightIcon && renderRightIcon()}
                        </View>
                        :
                        <View style={styles.formSingleRowRight}>
                            {
                                hasPermission ?
                                    <>
                                        {
                                            rightIcon || hideRightIcon ?
                                                null
                                                :
                                                <Image style={styles.rightIcon} source={require('./../../assets/icons/right-icon.png')} />
                                        }
                                        {
                                            rightIcon ?
                                                <Image style={{ width: px2dp(18), height: px2dp(18), tintColor: '#909399' }} source={rightIcon} />
                                                :
                                                null
                                        }
                                    </>
                                    :
                                    null
                            }
                        </View>
                }
            </TouchableOpacity>
        )
    }
}

const styles = StyleSheet.create({
    formSingleRow: {
        width: px2dp(330),
        flexDirection: 'row',
        justifyContent: 'space-between',
        alignItems: 'flex-start',
        marginBottom: 1,
        borderBottomWidth: onePx,
        borderBottomColor: colors.borderLineColor,
        marginHorizontal: px2dp(10),
        paddingVertical: px2dp(12)
    },

    formGroupRowInline: {
        width: px2dp(324),
    },

    formSingleRowLeft: {
        width: px2dp(280),
        justifyContent: 'center',
        alignItems: 'flex-start',
    },

    formSingleRowRight: {
        flex: 1,
        height: '100%',
        flexDirection: 'row',
        justifyContent: 'flex-end',
        alignItems: 'center'
    },

    rightIcon: {
        width: px2dp(14),
        height: px2dp(14),
        tintColor: '#909399',
    },

    formGroupTitleContainer: {
        width: '100%',
        height: px2dp(24),
        justifyContent: 'center',
        alignItems: 'flex-start',
        marginBottom: px2dp(4)
    },

    valueContainer: {
        width: '100%',
        height: px2dp(28),
        justifyContent: 'center',
        alignItems: 'flex-start'
    },

    formRowTitle: {
        fontSize: 16,
        lineHeight: px2dp(20),
        color: colors.blackColor,
    },

    formRowPlaceHolderText: {
        fontSize: 14,
        height: px2dp(20),
        lineHeight: px2dp(20),
        color: colors.placeholderColor
    },

    formValueText: {
        // height: px2dp(20),
        lineHeight: px2dp(20),
        fontSize: 14,
        color: '#303133'
    },

    formRowPlaceHolderTextInput: {
        fontSize: 14,
        color: '#303133',
        width: '100%',
        height: px2dp(20),
        paddingVertical: px2dp(0),
        paddingHorizontal: px2dp(0),
        flexDirection: 'row',
        justifyContent: 'flex-start',
        alignItems: 'center',
    }
})