import React from 'react';
import {
    SafeAreaView,
    ScrollView,
    StatusBar,
    StyleSheet,
    Text,
    Image,
    TouchableOpacity,
    View,
    DeviceEventEmitter
} from 'react-native';
import API from '../../api';
import DataBaseTableName from '../../database/DataBaseTableName';
import mockAction from './../../sevices/mockAction';
import { navigate } from '../../NavigationService';
import { colors, filterSqlRows, getLocalTime, isEmpty, myConfirm, onePx, px2dp, toast, toastShort, validResponseCode } from '../../utils';
import { BjTypeCommonResearch, BjTypeResearchConnection, BjTypeResearchNameDict } from '../../utils/types';
import KitDashBorderLine from './KitDashBorderLine';
import KitCheckBox from './KitCheckBox';
import KitLoadingToast from './KitLoadingToast';

interface Props {
    item: BjTypeCommonResearch
    showLoading?: Function
    hideLoading?: Function
    handleRefreshTab?: Function
    selection?: boolean
    selectionType?: 'radio' | 'checkBox'
    onSelectChange?: Function
    selectedDataList?: Array<BjTypeCommonResearch>
    saveTempItemId?: Function
    inlineLayout?: boolean
    isRecycle?: boolean
}

interface State {
    checked: boolean
}

export default class KitResearchItem extends React.Component<Props, State> {
    constructor(props: Props) {
        super(props);
    };

    public currentTask = null;
    public refreshListener = null;
    public reviceFlashId = null;
    public delayTimer1 = null;
    public delayTimer2 = null;
    public delayTimer3 = null;
    public delayTimer4 = null;
    public delayTimer5 = null;
    public delayTimer6 = null;
    public containerRef = null;


    public readonly state: Readonly<State> = {
        checked: false,
    };

    /**
     * 折叠之后，此数据是调查主体、解开bodyData之后id就是下属的researchId
     */
    componentDidMount(): void {
        this.refreshListener = DeviceEventEmitter.addListener('refresh-task-console', () => {
            this.getCurrentItemStatus();
        })
        this.reviceFlashId = DeviceEventEmitter.addListener('flashId', (a) => {
            const { item } = this.props;
            if (item.id == a.id) {
                this.startFlash();
            }
        })
        this.getCurrentItemStatus();
    }

    componentWillUnmount(): void {
        this.delayTimer1 && clearTimeout(this.delayTimer1);
        this.delayTimer2 && clearTimeout(this.delayTimer2);
        this.delayTimer3 && clearTimeout(this.delayTimer3);
        this.refreshListener && this.refreshListener?.remove();
        this.setState = (state, callback) => {
            return;
        }
    }

    startFlash() {
        this.delayTimer1 = setTimeout(() => {
            this.containerRef?.setNativeProps({
                style: {
                    borderColor: '#ccc',
                }
            });
        }, 200);
        this.delayTimer2 = setTimeout(() => {
            this.containerRef?.setNativeProps({
                style: {
                    borderColor: '#fff',
                }
            });
        }, 400);
        this.delayTimer3 = setTimeout(() => {
            this.containerRef?.setNativeProps({
                style: {
                    borderColor: '#ccc',
                }
            });
        }, 600);
        this.delayTimer4 = setTimeout(() => {
            this.containerRef?.setNativeProps({
                style: {
                    borderColor: '#fff',
                }
            });
        }, 800);
    };

    getCurrentItemStatus() {

    };

    async jumpToTable() {
        try {
            const { item, showLoading, hideLoading, selection, saveTempItemId, isRecycle } = this.props;
            if (item.type == 'communityProfileResearch') {
                return this.jumpToNewResearchPage();
            }
            console.log("item", item)
            if (selection) {
                return false;
            }
            showLoading && showLoading();
            let requestMethod = null;
            let tablePageRouterName = '';
            let queryResearchConnectionParams: BjTypeResearchConnection = {

            };
            let researchType = item.type;
            switch (item.type) {
                // case 'communityProfileResearch':
                //     requestMethod = API.getCommunityProfileResearchDetailstV1;
                //     tablePageRouterName = 'ResearchCommonTablePage';
                //     queryResearchConnectionParams.communityProfileResearchId = item.researchId;
                //     break;
                case 'actualMeasurementResearch':
                    requestMethod = API.getActualMeasurementResearchDetailstV1;
                    tablePageRouterName = 'ResearchCommonTablePage';
                    queryResearchConnectionParams.actualMeasurementResearchId = item.researchId;
                    break;
                case 'sampleSquareResearch':
                    requestMethod = API.getSampleSquareResearchDetailstV1;
                    tablePageRouterName = 'ResearchCommonTablePage';
                    queryResearchConnectionParams.sampleSquareResearchId = item.researchId;
                    break;
                case 'sampleLineResearch':
                    requestMethod = API.getSampleLineResearchDetailstV1;
                    tablePageRouterName = 'ResearchCommonTablePage';
                    queryResearchConnectionParams.sampleLineResearchId = item.researchId;
                    break;
                default:
                    break;
            }
            let queryResearchConnectionTask = API.queryResearchConnection(queryResearchConnectionParams);
            console.log("queryResearchConnectionTask", JSON.stringify(queryResearchConnectionTask))
            // return false;
            if (!requestMethod) {
                hideLoading && hideLoading();
                return toast("请检查接口映射")
            }
            Promise.all([
                queryResearchConnectionTask,
                requestMethod({
                    id: selection ? item.id : item.researchId
                })
            ])
                .then(resList => {
                    console.log("这是首页调查详情", resList)
                    const researchConnectionRes = resList[0];
                    console.log("researchConnectionRes", JSON.stringify(researchConnectionRes))
                    const researchDetailsRes = resList[1];
                    if (validResponseCode(researchDetailsRes) && validResponseCode(researchConnectionRes)) {
                        let routeParams = {
                            researchInstance: researchDetailsRes.data.list ? researchDetailsRes.data.list[0] : researchDetailsRes.data.info,
                            researchType: researchType,
                            justView: isRecycle
                        }
                        if (researchConnectionRes.data.list.length) {
                            //@ts-ignore
                            routeParams.researchConnection = researchConnectionRes.data.list[0];
                        } else {
                            hideLoading && hideLoading();
                            return toast(
                                item.type == 'communityProfileResearch' ?
                                    "当前群落概况信息没有关联调查"
                                    :
                                    "请先填写群落概况信息"
                            )
                        }
                        if (item.type == 'communityProfileResearch') {
                            let connectResearchType: BjTypeResearchNameDict = "actualMeasurementResearch";
                            let connectResearchId = null;
                            let quereConnectResearchDetailsMethod = null;
                            let researchConnection: BjTypeResearchConnection = researchConnectionRes.data.list[0];
                            if (!isEmpty(researchConnection.actualMeasurementResearchId)) {
                                connectResearchType = 'actualMeasurementResearch';
                                connectResearchId = researchConnection['actualMeasurementResearchId'];
                                quereConnectResearchDetailsMethod = API.getActualMeasurementResearchDetailstV1;
                            } else if (!isEmpty(researchConnection.sampleLineResearchId)) {
                                connectResearchType = 'sampleLineResearch';
                                connectResearchId = researchConnection['sampleLineResearchId'];
                                quereConnectResearchDetailsMethod = API.getSampleLineResearchDetailstV1;
                            } else if (!isEmpty(researchConnection.sampleSquareResearchId)) {
                                connectResearchType = 'sampleSquareResearch';
                                connectResearchId = researchConnection['sampleSquareResearchId'];
                                quereConnectResearchDetailsMethod = API.getSampleSquareResearchDetailstV1;
                            }
                            if (connectResearchType && connectResearchId) {
                                console.log("routeParams------>", routeParams)
                                quereConnectResearchDetailsMethod && quereConnectResearchDetailsMethod({ id: connectResearchId })
                                    .then(res => {
                                        hideLoading && hideLoading();
                                        routeParams.researchInstance = res.data.list[0];
                                        // routeParams.researchType = item.type;

                                        navigate(tablePageRouterName, routeParams)
                                    })
                                    .catch(err => {
                                        hideLoading && hideLoading();
                                    })
                            }
                        } else {
                            hideLoading && hideLoading();
                            console.log("routeParams------>", routeParams)
                            DeviceEventEmitter.emit('add-common-research-float', { researchItem: item })
                            navigate(tablePageRouterName, routeParams)
                        }
                    } else {
                        toastShort("跳转失败，请稍后重试");
                    }
                })
                .catch(err => {
                    hideLoading && hideLoading();
                    toastShort("获取详情失败" + err)
                    console.log("err", err)
                })
        } catch (e) {
            toast("获取详情失败" + e)
        }
    };

    jumpToNewResearchPage() {
        try {
            const { item, showLoading, hideLoading, selection, saveTempItemId, isRecycle } = this.props;
            console.log("item", item)
            if (selection) {
                return false;
            }
            showLoading && showLoading();
            let requestMethod = null;
            let tablePageRouterName = '';
            let queryResearchConnectionParams: BjTypeResearchConnection = {

            };
            switch (item.type) {
                case 'communityProfileResearch':
                    requestMethod = API.getCommunityProfileResearchDetailstV1;
                    tablePageRouterName = 'NewCommunityProfileResearch';
                    queryResearchConnectionParams.communityProfileResearchId = item.researchId;
                    break;
                case 'actualMeasurementResearch':
                    requestMethod = API.getActualMeasurementResearchDetailstV1;
                    tablePageRouterName = 'NewActualMeasurementResearch';
                    queryResearchConnectionParams.actualMeasurementResearchId = item.researchId;
                    break;
                case 'sampleSquareResearch':
                    requestMethod = API.getSampleSquareResearchDetailstV1;
                    tablePageRouterName = 'NewSampleSquareResearch';
                    queryResearchConnectionParams.sampleSquareResearchId = item.researchId;
                    break;
                case 'sampleLineResearch':
                    requestMethod = API.getSampleLineResearchDetailstV1;
                    tablePageRouterName = 'NewSampleLineResearch';
                    queryResearchConnectionParams.sampleLineResearchId = item.researchId;
                    break;
                default:
                    break;
            }
            if (!requestMethod) {
                hideLoading && hideLoading();
                return toast("请检查接口映射")
            }
            let queryResearchConnectionTask = API.queryResearchConnection(queryResearchConnectionParams);
            Promise.all([
                queryResearchConnectionTask,
                requestMethod({
                    id: selection ? item.id : item.researchId
                })
            ])
                .then(resList => {
                    const researchConnectionRes = resList[0];
                    const researchDetailsRes = resList[1];
                    hideLoading && hideLoading();

                    if (validResponseCode(researchDetailsRes)) {
                        let routeParams = {
                            researchInstance: researchDetailsRes.data.list ? researchDetailsRes.data.list[0] : researchDetailsRes.data.info,
                            justView: isRecycle
                        }
                        if (researchConnectionRes.data.list.length) {
                            //@ts-ignore
                            routeParams.researchConnection = researchConnectionRes.data.list[0];
                        }
                        console.log("routeParams------>", routeParams)
                        navigate(tablePageRouterName, routeParams)
                    } else {
                        toastShort("跳转失败，请稍后重试");
                    }
                })
                .catch(err => {
                    hideLoading && hideLoading();
                    toastShort("获取详情失败" + err)
                    console.log("err", err)
                })
        } catch (e) {
            toast("获取详情失败" + e)
        }
    };

    checkIsAutoFinish(item) {
        const typeNameList = ["fungusResearchCollect", "plantResearchCollect", "waterResearchCollect", "soilResearchCollect"]
        return typeNameList.includes(item.type);
    }

    handleDeleteResearch() {
        const { isRecycle = false } = this.props;
        if (isRecycle) {
            let comfirmData = {
                title: "确认彻底删除此数据？数据将不能被找回",
                confirmText: "确认",
                confirmFun: this.cofmirmRealDelete.bind(this)
            };
            myConfirm(comfirmData)
        } else {
            let comfirmData = {
                title: "确认删除此数据？",
                confirmText: "确认",
                confirmFun: this.confirmToDeleteResearch.bind(this)
            };
            myConfirm(comfirmData)
        }
    };

    cofmirmRealDelete() {
        const { item, showLoading, hideLoading, handleRefreshTab } = this.props;
        showLoading && showLoading();
        mockAction.removeDataToDataBase(DataBaseTableName.researchCommonTable, item.id)
            .then(res => {
                hideLoading && hideLoading();
                toastShort("已彻底删除此数据");
                handleRefreshTab && handleRefreshTab();
            })
            .catch(err => {
                hideLoading && hideLoading();
            })
    }

    async confirmToDeleteResearch() {
        const { item, showLoading, hideLoading, handleRefreshTab } = this.props;
        showLoading && showLoading();
        if (item.type == 'communityProfileResearch') {
            hideLoading && hideLoading();
            return toastShort("请通过关联调查删除")
            //群落调查必须,先检查researchConnection;
            // let queryResearchConnectionParams: BjTypeResearchConnection = {
            //     communityProfileResearchId: item.researchId
            // };
            // let queryResearchConnectionRes = await API.queryResearchConnection(queryResearchConnectionParams);
            // if (queryResearchConnectionRes && validResponseCode(queryResearchConnectionRes) && queryResearchConnectionRes.data.list.length) {
            //     toastShort("请先删除该群落概况的关联调查")
            //     hideLoading && hideLoading();
            // } else {
            //     let params = {
            //         id: item.id,
            //         type: item.type,
            //         serialNumberAndCode: item.serialNumberAndCode
            //     };
            //     API.deleteCommonResearchListV1(params)
            //         .then(res => {
            //             console.log("删除结果----->", res)
            //             hideLoading && hideLoading();
            //             if (validResponseCode(res)) {
            //                 handleRefreshTab && handleRefreshTab();
            //             }
            //         })
            //         .catch(err => {
            //             console.log("删除失败", err)
            //             hideLoading && hideLoading();
            //         })
            // }
        } else {
            //直接删除，但同时需要删除researchConnection
            let queryResearchConnectionParams: BjTypeResearchConnection = {

            };
            switch (item.type) {
                case 'actualMeasurementResearch':
                    queryResearchConnectionParams.actualMeasurementResearchId = item.researchId;
                    break;
                case 'sampleSquareResearch':
                    queryResearchConnectionParams.sampleSquareResearchId = item.researchId;
                    break;
                case 'sampleLineResearch':
                    queryResearchConnectionParams.sampleLineResearchId = item.researchId;
                    break;
                default:
                    break;
            }
            let queryResearchConnectionRes = await API.queryResearchConnection(queryResearchConnectionParams);
            if (queryResearchConnectionRes && validResponseCode(queryResearchConnectionRes) && queryResearchConnectionRes.data.list.length) {
                let currentResearchConnection: BjTypeResearchConnection = queryResearchConnectionRes.data.list[0];
                const queryCommunityProfileResearchParams = {
                    researchId: currentResearchConnection.communityProfileResearchId
                }
                const communityProfileResearchRes = await mockAction.queryData(DataBaseTableName.researchCommonTable, queryCommunityProfileResearchParams);
                const communityProfileResearch: BjTypeCommonResearch = filterSqlRows(communityProfileResearchRes)[0];
                Promise.all([
                    API.deleteCommonResearchListV1({ id: item.id }),
                    API.deleteCommonResearchListV1({ id: communityProfileResearch.id }),
                ])
                    .then(res => {
                        toastShort("删除成功")
                        console.log("删除结果----->", res)
                        hideLoading && hideLoading();
                        handleRefreshTab && handleRefreshTab();
                        DeviceEventEmitter.emit('delete-research-item', { researchItem: item })
                        // if (validResponseCode(res)) {
                        //     handleRefreshTab && handleRefreshTab();
                        // }
                    })
                    .catch(err => {
                        console.log("删除失败", err)
                        hideLoading && hideLoading();
                    })
            } else {
                toastShort("当前调查关联信息已被解除，将直接删除")
                let params = {
                    id: item.id,
                    type: item.type,
                    serialNumberAndCode: item.serialNumberAndCode
                };
                API.deleteCommonResearchListV1(params)
                    .then(res => {
                        console.log("删除结果----->", res)
                        hideLoading && hideLoading();
                        if (validResponseCode(res)) {
                            handleRefreshTab && handleRefreshTab();
                        }
                    })
                    .catch(err => {
                        console.log("删除失败", err)
                        hideLoading && hideLoading();
                    })
            }
        }

    }

    adaptStatus() {
    };

    adaptSelected(): boolean {
        const { item, selectedDataList = [] } = this.props;
        const find = selectedDataList.find(ele => {
            return ele.id == item.id
        });
        return find ? true : false;
    };

    jumpToShareDataCenter() {
        const { item } = this.props;
        navigate('ShareDataCenter', { researchType: item.type, item })
    };

    adaptTargetSpeciesLiveType(type) {
        const options = [
            {
                key: 1,
                value: 'arbor',
                name: '乔木',
            },
            {
                key: 2,
                value: 'shrub',
                name: '灌木',
            },
            {
                key: 3,
                value: 'plant',
                name: '草本',
            },
            {
                key: 4,
                value: 'moss',
                name: '苔藓',
            },
        ];
        const findOption = options.find(option => {
            return option.value == type;
        });
        if (findOption) {
            return findOption.name
        }
        return "";
    };

    render() {
        const { item, selection, onSelectChange, inlineLayout = true, selectionType = 'radio' } = this.props;
        return (
            <View
                ref={(c) => this.containerRef = c}
                style={[
                    styles.item,
                    !inlineLayout ? { width: px2dp(350) } : null
                ]}
            >
                <View style={[
                    styles.itemTop,
                    !inlineLayout ? { width: px2dp(332) } : null
                ]}>
                    {
                        selection ?
                            <View style={[styles.itemTopLeft, { width: px2dp(200) }]}>
                                <Text style={{ fontSize: 16, color: '#303133', fontWeight: '500', lineHeight: 18 }}>{item.serialNumberAndCode}</Text>
                            </View>
                            :
                            <>
                                <View style={{ flex: 1, height: '100%', flexDirection: 'row', justifyContent: 'flex-start', alignItems: 'center' }}>
                                    <TouchableOpacity onPress={this.jumpToTable.bind(this)} style={[styles.itemTopLeft]}>
                                        <Text style={{ fontSize: 16, color: '#303133', textDecorationLine: 'underline', fontWeight: '500', lineHeight: 18 }}>
                                            {item.serialNumberAndCode}

                                        </Text>
                                        {
                                            item.type == 'sampleSquareResearch' ?
                                                <View style={styles.itemTag}>
                                                    <Text style={styles.itemTagText}>{this.adaptTargetSpeciesLiveType(item.targetSpeciesLiveType)}样方</Text>
                                                </View>
                                                :
                                                null
                                        }
                                    </TouchableOpacity>
                                </View>
                                <TouchableOpacity onPress={this.jumpToNewResearchPage.bind(this)} style={[styles.detailsBtn]}>
                                    <Image resizeMode={'contain'} style={styles.detailsIcon} source={require('./../../assets/icons/table-details-icon.png')} />
                                </TouchableOpacity>
                            </>
                    }
                </View>
                <View style={[
                    styles.itemBottom,
                    !inlineLayout ? { width: px2dp(332) } : null
                ]}>
                    <View style={styles.itemBottomLeft}>
                        <Text onPress={this.jumpToTable.bind(this)} style={{ fontSize: 14, color: '#909399' }}>{getLocalTime('YY:MM:DD', item.createDate)}</Text>
                        {
                            item.type == 'communityProfileResearch' ?
                                <TouchableOpacity onPress={this.jumpToTable.bind(this)} style={styles.statusDotContainer}>
                                    <View style={[styles.statusDot, { backgroundColor: '#a1a1a1' }]}></View>
                                    <Text style={{ fontSize: 14, color: '#7f7f7f' }}>关联信息</Text>
                                </TouchableOpacity>
                                :
                                <TouchableOpacity onPress={this.jumpToTable.bind(this)} style={styles.statusDotContainer}>
                                    {
                                        item.finishDate || this.checkIsAutoFinish(item) ?
                                            <>
                                                <View style={styles.statusDot}></View>
                                                <Text style={{ fontSize: 14, color: '#303133' }}>已完成</Text>
                                            </>
                                            :
                                            <>
                                                <View style={[styles.statusDot, { backgroundColor: colors.red }]}></View>
                                                <Text style={{ fontSize: 14, color: '#303133' }}>调查中</Text>
                                            </>
                                    }
                                </TouchableOpacity>
                        }
                    </View>
                    {
                        !selection ?
                            <TouchableOpacity onPress={this.handleDeleteResearch.bind(this)} style={styles.deleteBtn}>
                                <Image style={styles.deleteIcon} source={require('./../../assets/icons/delete.png')} />
                            </TouchableOpacity>
                            :
                            null
                    }
                </View>
                <KitDashBorderLine />
                {
                    selection ?
                        <View style={styles.checkBox}>
                            <KitCheckBox
                                type={selectionType}
                                checked={this.adaptSelected()}
                                onChange={onSelectChange}
                            />
                        </View>
                        :
                        null
                }
            </View>
        )
    }
}

const styles = StyleSheet.create({
    item: {
        position: 'relative',
        width: px2dp(280),
        height: px2dp(78),
        // backgroundColor: '#fff',
        flexDirection: 'column',
        justifyContent: 'space-between',
        alignItems: 'center',
        overflow: 'hidden',
        borderWidth: 2,
        borderColor: '#fff',
    },

    itemBottom: {
        width: px2dp(280),
        flexDirection: 'row',
        justifyContent: 'space-between',
        alignItems: 'center',
        paddingHorizontal: px2dp(4)
        // backgroundColor: 'red'
    },

    statusDotContainer: {
        flexDirection: 'row',
        justifyContent: 'flex-start',
        alignItems: 'center',
        marginHorizontal: px2dp(16)
    },

    statusDot: {
        width: px2dp(8),
        height: px2dp(8),
        borderRadius: px2dp(4),
        backgroundColor: colors.themeColor,
        marginRight: px2dp(4)
    },

    itemTop: {
        width: px2dp(280),
        paddingHorizontal: px2dp(4),
        height: px2dp(32),
        flexDirection: 'row',
        justifyContent: 'space-between',
        alignItems: 'center',
        overflow: 'hidden',
    },

    itemTopLeft: {
        height: '100%',
        flexDirection: 'row',
        justifyContent: 'flex-start',
        alignItems: 'center',
        paddingTop: px2dp(12)
    },

    detailsBtn: {
        width: px2dp(72),
        height: px2dp(32),
        justifyContent: 'center',
        alignItems: 'center',
        marginBottom: px2dp(-12),
        marginRight: px2dp(-18)
    },

    detailsIcon: {
        width: px2dp(20),
        height: px2dp(20),
        tintColor: colors.blueColor,
        opacity: 0.9
    },

    uploadIcon: {
        width: px2dp(24),
        height: px2dp(24),
        tintColor: colors.themeColor,
        marginRight: px2dp(2)
    },

    itemBottomLeft: {
        flexDirection: 'row',
        justifyContent: 'flex-start',
        alignItems: 'center'
    },

    deleteBtn: {
        width: px2dp(72),
        height: px2dp(32),
        justifyContent: 'center',
        alignItems: 'center',
        marginBottom: px2dp(0),
        marginRight: px2dp(-18)
    },

    deleteIcon: {
        width: px2dp(18),
        height: px2dp(18),
        tintColor: '#7f7f7f'
    },

    checkBox: {
        height: px2dp(78),
        width: px2dp(48),
        position: 'absolute',
        right: 0,
        zIndex: 999,
        justifyContent: 'center',
        alignItems: 'center',
        // paddingRight: px2dp(12)
    },

    itemTag: {
        height: px2dp(18),
        justifyContent: 'center',
        alignItems: 'center',
        backgroundColor: '#eee',
        marginHorizontal: px2dp(5),
        borderRadius: px2dp(3),
        paddingHorizontal: px2dp(5),
        marginBottom: px2dp(2)
    },

    itemTagText: {
        fontSize: 12,
        color: '#303133'
    }
})