//@ts-nocheck
import React, { Component } from 'react'
import { View, Text, StyleSheet, TouchableHighlight, TextInput, ScrollView, Animated, Easing, KeyboardAvoidingView } from 'react-native'
import { px2dp, onePx, colors, toastShort, isEmpty, filterSqlRows } from './../../utils';

interface Props {
    width?: string
    long?: string
    onConfirm?: Function,
    title?: string
    leftTitle?: string
    rightTitle?: string
    maxSizeLimit?: number
    leftPlaceHolder?: string
    leftValue?: string
    rightValue?: string
    rightPlaceHolder?: string
    descText1?: string
    descText2?: string
};


export default class KitSetCustomBlockSizeToast extends Component<Props, State> {
    constructor(props) {
        super(props);
        this.state = {
            opacity: new Animated.Value(0),
            number1: "",
            number2: "",
            loading: false,
            codeExist: false
        };
        this.active = false;
        this.show = this.show.bind(this)
    }

    public delayTimer = null;
    public delayTimer1 = null;
    public inputRef = null;

    componentWillUnmount() {
        this.delayHide && clearTimeout(this.delayHide);
        this.delayTimer && clearTimeout(this.delayTimer);
        this.inputRef && clearTimeout(this.inputRef);
        this.setState = (state, callback) => {
            return;
        }
    }

    show = ({ leftValue, rightValue }) => {
        if (leftValue && rightValue) {
            this.setState({ number1: leftValue, number2: rightValue })
        }
        this.toast.setNativeProps({
            style: {
                width: '100%',
                height: '100%',
                zIndex: 999
            }
        })
        Animated.timing(
            this.state.opacity,
            {
                toValue: 0.32,
                duration: 250,
                easing: Easing.in(),
                useNativeDriver: true
            }
        ).start();
        this.delayTimer = setTimeout(() => {
            this.inputRef && this.inputRef.focus();
        }, 200);
    }

    hide = () => {
        this.active = false;
        Animated.timing(
            this.state.opacity,
            {
                toValue: 0,
                duration: 100,
                easing: Easing.in(),
                useNativeDriver: true
            }
        ).start();
        this.delayHide = setTimeout(() => {
            this.toast.setNativeProps({
                style: {
                    width: 0,
                    height: 0,
                    zIndex: -1
                }
            })
        }, 100);
    };

    handleClose() {
        const { type } = this.props;
        const { onConfirm, leftTitle, rightTitle, leftPlaceHolder, rightPlaceHolder } = this.props;
        const { number1, number2 } = this.state;
        if (isEmpty(number1)) {
            return toastShort(leftPlaceHolder)
        }
        if (isEmpty(number2)) {
            return toastShort(rightPlaceHolder)
        }
        onConfirm && onConfirm({
            containerLong: number1,
            containerWidth: number2
        })
        this.hide();
    }

    firstNumberChange(text) {
        const { maxSizeLimit } = this.props;
        const { number1 } = this.state;
        let testText = text.replace(/[^\d^\.]+/g, '');
        let arr1 = testText.split('.');
        if (arr1.length > 2) {
            return toastShort("只能输入一个小数点");
        } else {
            if (arr1[1] && arr1[1].length > 2) {
                return toastShort("只能输入一个小数点后两位数");
            }
        }
        if (Number(testText) > maxSizeLimit) {
            toastShort(`最大可输入${maxSizeLimit}`)
            this.setState({ number1 })
        } else {
            this.setState({ number1: testText })
        }
    };

    onSecondNumberChange(text) {
        const { maxSizeLimit } = this.props;
        const { number2 } = this.state;
        let testText = text.replace(/[^\d^\.]+/g, '');
        let arr1 = testText.split('.');
        if (arr1.length > 2) {
            return toastShort("只能输入一个小数点");
        } else {
            if (arr1[1] && arr1[1].length > 2) {
                return toastShort("只能输入一个小数点后两位数");
            }
        }
        if (Number(testText) > maxSizeLimit) {
            toastShort(`最大可输入${maxSizeLimit}`)
            this.setState({ number2 })
        } else {
            this.setState({ number2: testText })
        }
    };

    render() {
        const {
            title = "", leftTitle = "", rightTitle = "", existText = "",
            leftPlaceHolder = "", rightPlaceHolder, maxSizeLimit = 20,
            descText1, descText2
        } = this.props;
        const {
            number1, number2, loading, codeExist
        } = this.state;
        return (
            <View ref={(c) => this.toast = c} style={styles.alertContainer}>
                <Animated.View style={[styles.alertOverlay, { opacity: this.state.opacity }]}>
                </Animated.View>
                <KeyboardAvoidingView behavior={'height'} style={{ width: '100%', flex: 1, justifyContent: 'center', alignItems: 'center' }}>
                    <View style={styles.alertContent}>
                        <View style={styles.alertBody}>
                            <View style={styles.alertBodyTop}>
                                <Text style={{ flex: 1, fontSize: 18, color: '#7F7F7F' }}>{title}</Text>
                            </View>
                            <View style={styles.alertBodyCenter}>
                                <View style={styles.alertBodyCenterHalf}>
                                    <View style={{ width: '100%', flexDirection: 'row', justifyContent: 'center', alignItems: 'center' }}>
                                        <TextInput
                                            ref={(c) => this.inputRef = c}
                                            style={[styles.alertBodyInput, { flex: 1 }]}
                                            placeholder={leftPlaceHolder}
                                            keyboardType={'numeric'}
                                            maxLength={6}
                                            value={number1 ? number1 + '' : ''}
                                            onChangeText={this.firstNumberChange.bind(this)}
                                        />
                                        <Text style={{ fontSize: 16, color: '#333', marginLeft: px2dp(6) }}>m</Text>
                                    </View>
                                    {/* <Text style={{ fontSize: 14, color: '#aaa', marginTop: px2dp(6) }}>支持数字1-{maxSizeLimit}</Text> */}
                                </View>
                                <View style={styles.testLine}>
                                    <Text style={{ fontSize: 20, color: '#555' }}>x</Text>
                                </View>
                                <View style={styles.alertBodyCenterHalf}>
                                    <View style={{ width: '100%', flexDirection: 'row', justifyContent: 'center', alignItems: 'center' }}>
                                        <TextInput
                                            style={styles.alertBodyInput}
                                            placeholder={rightPlaceHolder}
                                            keyboardType={'numeric'}
                                            maxLength={6}
                                            value={number2 ? number2 + '' : ''}
                                            onChangeText={this.onSecondNumberChange.bind(this)}
                                        />
                                        <Text style={{ fontSize: 16, color: '#333', marginLeft: px2dp(6) }}>m</Text>
                                    </View>
                                    {/* <Text style={{ fontSize: 14, color: '#aaa', marginTop: px2dp(6) }}>支持数字1-{maxSizeLimit}</Text> */}
                                </View>
                            </View>
                            <View style={{ width: '100%', justifyContent: 'center', alignItems: 'flex-start', marginTop: px2dp(-12), marginBottom: px2dp(10) }}>
                                <Text style={{ fontSize: 14, color: '#aaa', marginTop: px2dp(2), textAlign: 'left' }}>{descText1 ? descText1 : ''}</Text>
                                <Text style={{ fontSize: 14, color: '#aaa', marginTop: px2dp(2), textAlign: 'left' }}>{descText2 ? descText2 : ''}</Text>
                            </View>
                        </View>
                        <View style={styles.borderTop}></View>
                        <View style={styles.alertFooter}>
                            <TouchableHighlight style={styles.btn} underlayColor={'#f2f2f2'} onPress={() => this.hide()} >
                                <Text style={{ fontSize: 17, color: colors.blackColor, fontWeight: '400' }}>取消</Text>
                            </TouchableHighlight>
                            <View style={styles.border}></View>
                            <TouchableHighlight style={styles.btn} underlayColor={'#f2f2f2'} onPress={() => this.handleClose()} >
                                <Text style={{ fontSize: 17, color: colors.blackColor, fontWeight: '400' }}>确定</Text>
                            </TouchableHighlight>
                        </View>
                    </View>
                </KeyboardAvoidingView>
            </View>
        )
    }
}


const styles = StyleSheet.create({
    alertContainer: {
        position: 'absolute',
        width: '0%',
        height: '0%',
        justifyContent: 'center',
        alignItems: 'center',
        overflow: 'hidden',
        zIndex: -1
    },

    alertOverlay: {
        position: 'absolute',
        top: 0,
        left: 0,
        right: 0,
        bottom: 0,
        width: '100%',
        height: '100%',
        backgroundColor: '#000'
    },

    alertContent: {
        width: px2dp(320),
        backgroundColor: '#fff',
        borderRadius: px2dp(8),
        justifyContent: 'space-between',
        alignItems: 'center',
        overflow: 'hidden'
    },

    alertHeader: {
        width: '100%',
        justifyContent: 'center',
        alignItems: 'center',
        // backgroundColor: '#999',
        paddingTop: px2dp(18)
    },

    alertBody: {
        width: '100%',
        height: px2dp(142),
        justifyContent: 'flex-start',
        alignItems: 'center',
        paddingHorizontal: px2dp(18),
        paddingTop: px2dp(16),
    },

    alertBodyTop: {
        width: '100%',
        flexDirection: 'row',
        justifyContent: 'space-between',
        alignItems: 'center'
    },

    alertBodyTopRight: {
        flex: 1,
        height: px2dp(24),
        flexDirection: 'row',
        justifyContent: 'flex-end',
        alignItems: 'center'
    },

    alertBodyCenter: {
        flex: 1,
        flexDirection: 'row',
        justifyContent: 'center',
        alignItems: 'center',
        paddingBottom: px2dp(2)
    },

    alertBodyCenterHalf: {
        flex: 1,
        justifyContent: 'flex-start',
        alignItems: 'flex-start'
    },

    alertBodyInput: {
        // width: '100%',
        flex: 1,
        height: px2dp(36),
        borderWidth: 1,
        borderColor: '#e9e9e9',
        borderRadius: px2dp(4),
        paddingHorizontal: px2dp(6),
        paddingVertical: px2dp(0),
        fontSize: 14,
        color: colors.blackColor
    },

    title: {
        fontSize: 16,
        color: '#000',
        fontWeight: '600',
        lineHeight: 25,
        textAlign: 'center',
        letterSpacing: 0.8
    },

    borderTop: {
        borderBottomColor: '#d2d2d2',
        borderBottomWidth: onePx,
        width: px2dp(280),
        height: 1,
    },

    alertFooter: {
        width: '100%',
        height: px2dp(52),

        justifyContent: 'center',
        alignItems: 'center',
        flexDirection: 'row',
    },

    btn: {
        flex: 1,
        height: '100%',
        justifyContent: 'center',
        alignItems: 'center'
    },

    border: {
        width: 1,
        height: px2dp(32),
        borderRightColor: '#d2d2d2',
        borderRightWidth: onePx
    },

    testLine: {
        width: px2dp(24),
        justifyContent: 'center',
        alignItems: 'center',
        // backgroundColor: 'red',
        // marginTop: px2dp(-24)
    }
})