import React, { useState } from 'react'
import { View, Text, StyleSheet, TouchableOpacity, Image, StatusBar, ViewStyle } from 'react-native';
import { back } from '../../NavigationService';
import { px2dp, onePx, size, statusBarHeight, isIos, colors } from './../../utils';

interface Props {
    rightComponent?: any;
    title?: string;
    subTitle?: string
    blod?: boolean;
    noBoder?: boolean;
    style?: ViewStyle;
    hideMessage?: boolean;
    mode?: 'dark' | 'light';
    useCancelText?: boolean;
    handleBack?: Function,
    backgroundColor?: string
    customBackIcon?: any
    hideBack?: boolean
    sideWidth?: number
};

const NormalHeader = (props: Props) => {
    const {
        rightComponent, title, blod = false, noBoder, style, hideMessage,
        mode = "light", useCancelText, backgroundColor, customBackIcon = "",
        hideBack = false, sideWidth = px2dp(100), subTitle = ""
    } = props;

    React.useEffect(() => {
        // if (mode === 'light') {
        //     StatusBar.setBarStyle('light-content');
        // } else {
        //     StatusBar.setBarStyle('dark-content');
        // }
    }, [])

    const goBack = () => {
        const { handleBack } = props;
        if (handleBack) {
            handleBack && handleBack();
        } else {
            back();
        }
    };


    const confirmBack = () => {
        let confirmData = {
            title: '确认取消编辑？系统将不会保留您的更改',
            confirmText: '确认',
            confirmFun: goBack
        };
        // myConfirm(confirmData)
    };

    return (
        <View
            style={[
                styles.headerContainer,
                mode == 'dark' ? { backgroundColor: '#fff', borderBottomWidth: onePx, borderBottomColor: '#d2d2d2' } : null,
                backgroundColor ? { backgroundColor: backgroundColor } : null,
                noBoder ? { borderBottomWidth: 0 } : null,
                style
            ]}>
            <View style={[styles.sideContainer, { width: sideWidth }]}>
                {
                    hideBack ?
                        null
                        :
                        <>
                            {
                                useCancelText ?
                                    <TouchableOpacity onPress={() => confirmBack()} style={styles.backPress}>
                                        <Text style={{ fontSize: 15, color: '#303133', fontWeight: '500' }}>取消</Text>
                                    </TouchableOpacity>
                                    :
                                    <>
                                        {
                                            customBackIcon ?
                                                <TouchableOpacity onPress={() => goBack()} style={styles.backPress}>
                                                    <Image style={[styles.headerIconMini, mode === 'dark' ? { tintColor: '#303133' } : null]} source={customBackIcon} />
                                                </TouchableOpacity>
                                                :
                                                <TouchableOpacity onPress={() => goBack()} style={styles.backPress}>
                                                    {
                                                        isIos() ?
                                                            <Image style={[styles.headerIcon, mode === 'dark' ? { tintColor: '#303133' } : null]} source={require('./../../assets/icons/back-icon-ios.png')} />
                                                            :
                                                            <Image style={[styles.headerIcon, mode === 'dark' ? { tintColor: '#303133' } : null]} source={require('./../../assets/icons/back-icon.png')} />
                                                    }
                                                </TouchableOpacity>
                                        }
                                    </>

                            }
                        </>
                }
            </View>
            <View style={{ flex: 1, justifyContent: 'center', alignItems: 'center', height: size.head_height }}>
                <Text
                    numberOfLines={1}
                    style={[
                        styles.headerTitle,
                        blod ? { fontWeight: '700' } : { fontWeight: '400' },
                        mode === 'dark' ? { color: '#303133' } : null,

                    ]}
                >{title ? title : ""}</Text>
                {
                    subTitle ?
                        <Text style={{ fontSize: 10, color: '#fff', marginTop: px2dp(-1) }}>{subTitle}</Text>
                        :
                        null
                }
            </View>
            <View style={[styles.sideContainer, { justifyContent: 'flex-end', width: sideWidth }]}>
                {rightComponent}
            </View>
        </View>
    )
};

const styles = StyleSheet.create({
    headerContainer: {
        width: '100%',
        height: size.head_height + statusBarHeight,
        paddingTop: statusBarHeight,
        flexDirection: 'row',
        justifyContent: 'space-between',
        alignItems: 'center',
        backgroundColor: colors.themeColor,
        zIndex: 99,
    },

    sideContainer: {
        width: px2dp(100),
        flexDirection: 'row',
        height: size.head_height,
        alignItems: 'center',
        justifyContent: 'flex-start',
        // backgroundColor: 'red'
    },

    backPress: {
        height: size.head_height,
        paddingHorizontal: px2dp(12),
        justifyContent: 'center',
        alignItems: 'center'
    },

    headerTitle: {
        fontSize: 18,
        color: '#fff',
        fontWeight: '500',
        maxWidth: px2dp(240),
        textAlign: 'center'
    },

    headerIcon: {
        width: px2dp(20),
        height: px2dp(20),
        tintColor: '#fff'
    },

    headerIconMini: {
        width: px2dp(18),
        height: px2dp(18),
        tintColor: '#fff'
    },

    messageBox: {
        paddingHorizontal: px2dp(12),
        position: 'relative',
        marginTop: px2dp(-3)
    },

    messageIcon: {
        width: px2dp(24),
        height: px2dp(24),
    },

    messageNumBox: {
        position: 'absolute',
        top: px2dp(-2),
        right: px2dp(10),
        width: px2dp(18),
        height: px2dp(14),
        backgroundColor: colors.redColor,
        zIndex: 999,
        borderRadius: px2dp(8),
        justifyContent: 'center',
        alignItems: 'center'
    },

    messageNum: {
        fontSize: 8,
        color: '#fff',
        opacity: 0.9
    },
})

export default NormalHeader;