import React from 'react';
import {
    SafeAreaView,
    ScrollView,
    StatusBar,
    StyleSheet,
    Text,
    Image,
    TouchableOpacity,
    View,
    DeviceEventEmitter
} from 'react-native';
import comStyles from '../assets/styles/com-style';
import { setMapConfig } from '../redux/actiions';
import { colors, onePx, px2dp, toast } from '../utils';
import { BjTypeMapConfig } from '../utils/types';
import redux from './../redux/store';

interface Props {
}

interface State {
    mapLayerType: 'outdoor' | 'satellite',
    mapConfig: BjTypeMapConfig
}

export default class MapTool extends React.Component<Props, State> {
    constructor(props: Props) {
        super(props);
    };

    public _state = redux.getState();

    public readonly state: Readonly<State> = {
        mapLayerType: 'satellite',
        mapConfig: this._state.mapConfig
    };

    switchMapType(type) {
        let { mapConfig } = this.state;
        mapConfig.layerType = type;
        this.saveMapConfig(mapConfig)
    };

    switchRiverShow() {
        let { mapConfig } = this.state;
        mapConfig.showRiver = !mapConfig.showRiver;
        if (mapConfig.showRiver) {
            mapConfig.showVe = false;
            mapConfig.showVeLabel = false;
        }
        this.saveMapConfig(mapConfig)
    }

    switchVeShow() {
        let { mapConfig } = this.state;
        mapConfig.showVe = !mapConfig.showVe;
        if (mapConfig.showVe) {
            mapConfig.showRiver = false;
            mapConfig.showRiverLabel = false;
        }
        this.saveMapConfig(mapConfig)
    }

    switchResearchPlotShow() {
        let { mapConfig } = this.state;
        mapConfig.showResearchPlot = !mapConfig.showResearchPlot;
        this.saveMapConfig(mapConfig)
    }

    switchResearchLineShow() {
        let { mapConfig } = this.state;
        mapConfig.showResearchLine = !mapConfig.showResearchLine;
        this.saveMapConfig(mapConfig)
    }

    switchRiverLabelShow() {
        let { mapConfig } = this.state;
        mapConfig.showRiverLabel = !mapConfig.showRiverLabel;
        this.saveMapConfig(mapConfig)
    }

    switchVeLabelShow() {
        let { mapConfig } = this.state;
        mapConfig.showVeLabel = !mapConfig.showVeLabel;
        this.saveMapConfig(mapConfig)
    }

    saveMapConfig(mapConfig) {
        this.setState({ mapConfig })
        DeviceEventEmitter.emit("map-config-change", { mapConfig })
        redux.dispatch(setMapConfig(mapConfig))
    }

    switchResearchDataShow() {
        let { mapConfig } = this.state;
        mapConfig.showResearchData = !mapConfig.showResearchData;
        this.saveMapConfig(mapConfig)
    }

    switchTrackShow() {
        let { mapConfig } = this.state;
        mapConfig.showTrackLine = !mapConfig.showTrackLine;
        this.saveMapConfig(mapConfig)
    }

    switchGridShow() {
        let { mapConfig } = this.state;
        mapConfig.showGridLine = !mapConfig.showGridLine;
        this.saveMapConfig(mapConfig)
    }

    switchResearchDataLabelShow() {
        let { mapConfig } = this.state;
        mapConfig.showResearchDataLabel = !mapConfig.showResearchDataLabel;
        this.saveMapConfig(mapConfig)
    }


    render() {
        const { mapConfig } = this.state;;
        return (
            <ScrollView
                style={{ width: '100%', backgroundColor: '#fff', flex: 1 }}
                contentContainerStyle={comStyles.listContent}
            >
                <View style={styles.row}>
                    <Text style={[styles.rowTitle, { fontSize: 18 }]}>选择底图</Text>
                </View>
                <View style={styles.box}>
                    <View style={styles.mapTypeBoxContainer}>
                        {
                            mapConfig.layerType === 'outdoor' ?
                                <View style={styles.mapTypeBox}>
                                    <View style={[styles.mapTypeImgBox, { borderColor: colors.themeColor }]}>
                                        <Image resizeMode={'cover'} style={[styles.mapTypeImg]} source={require('./../assets/icons/map-default-img.png')} />
                                        <View style={styles.mapCheckedRow}>
                                            <Image style={styles.mapCheckedIcon} source={require('./../assets/icons/checked-icon.png')} />
                                        </View>
                                    </View>
                                    <Text style={styles.rowTitle}>普通地图</Text>
                                </View>
                                :
                                <TouchableOpacity onPress={() => this.switchMapType('outdoor')} style={styles.mapTypeBox}>
                                    <View style={styles.mapTypeImgBox}>
                                        <Image resizeMode={'cover'} style={styles.mapTypeImg} source={require('./../assets/icons/map-default-img.png')} />
                                    </View>
                                    <Text style={styles.rowTitle}>普通地图</Text>
                                </TouchableOpacity>
                        }
                        {
                            mapConfig.layerType === 'satellite' ?
                                <View style={styles.mapTypeBox}>
                                    <View style={[styles.mapTypeImgBox, { borderColor: colors.themeColor }]}>
                                        <Image resizeMode={'cover'} style={styles.mapTypeImg} source={require('./../assets/icons/map-satellite-img.jpeg')} />
                                        <View style={styles.mapCheckedRow}>
                                            <Image style={styles.mapCheckedIcon} source={require('./../assets/icons/checked-icon.png')} />
                                        </View>
                                    </View>
                                    <Text style={styles.rowTitle}>卫星地图</Text>
                                </View>
                                :
                                <TouchableOpacity onPress={() => this.switchMapType('satellite')} style={styles.mapTypeBox}>
                                    <View style={styles.mapTypeImgBox}>
                                        <Image resizeMode={'cover'} style={styles.mapTypeImg} source={require('./../assets/icons/map-satellite-img.jpeg')} />
                                    </View>
                                    <Text style={styles.rowTitle}>卫星地图</Text>
                                </TouchableOpacity>
                        }
                    </View>
                </View>
                <View style={[styles.row, { marginTop: px2dp(24), marginBottom: px2dp(12) }]}>
                    <Text style={[styles.rowTitle, { fontSize: 18 }]}>添加图层</Text>
                </View>
                <View style={styles.col}>
                    <View style={styles.optionRow}>
                        <View style={styles.optionRowLeft}>
                            <View style={styles.iconBorder}>
                                <Image source={require('./../assets/icons/map-geo-icon-outline.png')} style={styles.rowIcon1} />
                            </View>
                            <Text>调查边界</Text>
                        </View>
                        <View style={{ height: '100%', justifyContent: 'flex-end', flexDirection: 'row', alignItems: 'center' }}>
                            <TouchableOpacity onPress={() => toast("暂无图层数据")} style={styles.optionBtn}>
                                <Image source={require('./../assets/icons/map-eye-icon.png')} style={[styles.optionRightIcon]} />
                            </TouchableOpacity>
                        </View>
                    </View>
                    <View style={styles.optionRow}>
                        <View style={styles.optionRowLeft}>
                            <TouchableOpacity style={[styles.iconBorder]}>
                                <Image source={require('./../assets/icons/grid-icon.png')} style={[styles.rowIcon1, { borderRadius: 0, width: px2dp(24), height: px2dp(24) }]} />
                            </TouchableOpacity>
                            <Text>调查网格</Text>
                        </View>
                        <View style={{ height: '100%', justifyContent: 'flex-end', flexDirection: 'row', alignItems: 'center' }}>
                            <TouchableOpacity
                                onPress={() => toast("暂无图层数据")}
                                style={styles.optionBtn}
                            >
                                <Image source={require('./../assets/icons/map-eye-icon.png')} style={[styles.optionRightIcon, { tintColor: mapConfig.showGridLine ? colors.themeColor : '#909399' }]} />
                            </TouchableOpacity>
                        </View>
                    </View>
                    {/* <View style={styles.optionRow}>
                        <View style={styles.optionRowLeft}>
                            <View style={styles.iconBorder}>
                                <Image resizeMode={'contain'} source={require('./../assets/map-geo-icon-river.png')} style={styles.rowIcon1} />
                            </View>
                            <Text>湖泊水系</Text>
                        </View>
                        <View style={{ height: '100%', justifyContent: 'flex-end', flexDirection: 'row', alignItems: 'center' }}>
                            <TouchableOpacity onPress={this.switchRiverLabelShow.bind(this)} style={[styles.optionBtn, { paddingRight: px2dp(3) }]}>
                                <Text style={{ fontSize: 14, color: mapConfig.showRiverLabel ? colors.greenTextColor : '#909399' }}>Lab</Text>
                            </TouchableOpacity>
                            <TouchableOpacity onPress={this.switchRiverShow.bind(this)} style={styles.optionBtn}>
                                <Image source={require('./../assets/map-eye-icon.png')} style={[styles.optionRightIcon, { tintColor: mapConfig.showRiver ? colors.themeColor : '#909399' }]} />
                            </TouchableOpacity>
                        </View>
                    </View> */}
                    {/* <View style={styles.optionRow}>
                        <View style={styles.optionRowLeft}>
                            <View style={styles.iconBorder} >
                                <Image source={require('./../assets/map-geo-icon-footer-road.png')} style={styles.rowIcon1} />
                            </View>
                            <Text>步行路线</Text>
                        </View>
                        <TouchableOpacity onPress={() => toast("暂不支持取消")} style={[styles.optionBtn]}>
                            <Image source={require('./../assets/map-eye-icon.png')} style={[styles.optionRightIcon,{tintColor: colors.themeColor}]} />
                        </TouchableOpacity>
                    </View> */}
                    {/* <View style={styles.optionRow}>
                        <View style={styles.optionRowLeft}>
                            <TouchableOpacity style={[styles.iconBorder, { borderColor: '#fff' }]}>
                                <Image source={require('./../assets/12.png')} style={[styles.rowIcon]} />
                            </TouchableOpacity>
                            <Text>植被类型</Text>
                        </View>
                        <View style={{ height: '100%', justifyContent: 'flex-end', flexDirection: 'row', alignItems: 'center' }}>
                            <TouchableOpacity onPress={this.switchVeLabelShow.bind(this)} style={[styles.optionBtn, { paddingRight: px2dp(3) }]}>
                                <Text style={{ fontSize: 14, color: mapConfig.showVeLabel ? colors.greenTextColor : '#909399' }}>Lab</Text>
                            </TouchableOpacity>
                            <TouchableOpacity onPress={this.switchVeShow.bind(this)} style={styles.optionBtn}>
                                <Image source={require('./../assets/map-eye-icon.png')} style={[styles.optionRightIcon, { tintColor: mapConfig.showVe ? colors.themeColor : '#909399' }]} />
                            </TouchableOpacity>
                        </View>
                    </View> */}
                    {/* <View style={styles.optionRow}>
                        <View style={styles.optionRowLeft}>
                            <TouchableOpacity style={[styles.iconBorder, { borderColor: '#fff' }]}>
                                <Image source={require('./../assets/point.jpeg')} style={[styles.rowIcon1]} />
                            </TouchableOpacity>
                            <Text>样地预设</Text>
                        </View>
                        <TouchableOpacity onPress={this.switchResearchPlotShow.bind(this)} style={styles.optionBtn}>
                            <Image source={require('./../assets/map-eye-icon.png')} style={[styles.optionRightIcon, { tintColor: mapConfig.showResearchPlot ? colors.themeColor : '#909399' }]} />
                        </TouchableOpacity>
                    </View>
                    <View style={styles.optionRow}>
                        <View style={styles.optionRowLeft}>
                            <TouchableOpacity style={[styles.iconBorder, { borderColor: '#fff' }]}>
                                <Image source={require('./../assets/line.jpeg')} style={[styles.rowIcon1]} />
                            </TouchableOpacity>
                            <Text>样线预设</Text>
                        </View>
                        <TouchableOpacity onPress={this.switchResearchLineShow.bind(this)} style={styles.optionBtn}>
                            <Image source={require('./../assets/map-eye-icon.png')} style={[styles.optionRightIcon, { tintColor: mapConfig.showResearchLine ? colors.themeColor : '#909399' }]} />
                        </TouchableOpacity>
                    </View> */}
                    <View style={styles.optionRow}>
                        <View style={styles.optionRowLeft}>
                            <TouchableOpacity style={[styles.iconBorder]}>
                                <Image
                                    resizeMode={'cover'}
                                    source={require('./../assets/icons/watch.png')}
                                    style={[styles.rowIcon1, { width: px2dp(24), height: px2dp(24), borderRadius: 0, tintColor: '#606266' }]}
                                />
                            </TouchableOpacity>
                            <Text>调查数据</Text>
                        </View>
                        <View style={{ height: '100%', justifyContent: 'flex-end', flexDirection: 'row', alignItems: 'center' }}>
                            <TouchableOpacity onPress={this.switchResearchDataLabelShow.bind(this)} style={[styles.optionBtn, { paddingRight: px2dp(3) }]}>
                                <Text style={{ fontSize: 14, color: mapConfig.showResearchDataLabel ? colors.greenTextColor : '#909399' }}>Lab</Text>
                            </TouchableOpacity>
                            <TouchableOpacity onPress={this.switchResearchDataShow.bind(this)} style={styles.optionBtn}>
                                <Image source={require('./../assets/icons/map-eye-icon.png')} style={[styles.optionRightIcon, { tintColor: mapConfig.showResearchData ? colors.themeColor : '#909399' }]} />
                            </TouchableOpacity>
                        </View>
                    </View>
                    {/* <View style={styles.optionRow}>
                        <View style={styles.optionRowLeft}>
                            <TouchableOpacity style={[styles.iconBorder]}>
                                <Image source={require('./../assets/track-icon.png')} style={[styles.rowIcon1,{borderRadius: 0}]} />
                            </TouchableOpacity>
                            <Text>轨迹记录</Text>
                        </View>
                        <View style={{ height: '100%', justifyContent: 'flex-end', flexDirection: 'row', alignItems: 'center' }}>
                            <TouchableOpacity onPress={this.switchTrackShow.bind(this)} style={styles.optionBtn}>
                                <Image source={require('./../assets/map-eye-icon.png')} style={[styles.optionRightIcon, { tintColor: mapConfig.showTrackLine ? colors.themeColor : '#909399' }]} />
                            </TouchableOpacity>
                        </View>
                    </View> */}

                </View>
            </ScrollView>
        )
    }
}


const styles = StyleSheet.create({
    row: {
        width: '100%',
        height: px2dp(42),
        flexDirection: 'row',
        justifyContent: 'flex-start',
        alignItems: 'center',
        paddingHorizontal: px2dp(12),
        paddingTop: px2dp(6)
    },

    rowTitle: {
        fontSize: 14,
        color: colors.blackColor
    },

    box: {
        width: '100%',
        backgroundColor: '#fff'
    },

    col: {
        width: '100%',
        flexDirection: 'column',
        justifyContent: 'flex-start',
        alignItems: 'center'
    },

    optionRow: {
        width: px2dp(232),
        height: px2dp(72),
        flexDirection: 'row',
        justifyContent: 'space-between',
        alignItems: 'center',
        borderTopColor: '#d2d2d2',
        borderTopWidth: onePx,
    },

    optionRowLeft: {
        height: '100%',
        flexDirection: 'row',
        justifyContent: 'flex-start',
        alignItems: 'center',
    },

    mapTypeBoxContainer: {
        width: '100%',
        flexDirection: 'row',
        justifyContent: 'space-between',
        alignItems: 'center',
        paddingHorizontal: px2dp(12),
        paddingVertical: px2dp(12)
    },

    mapTypeBox: {
        position: 'relative',
        width: px2dp(112),
        justifyContent: 'center',
        alignItems: 'center',
    },

    mapTypeImgBox: {
        width: px2dp(112),
        height: px2dp(88),
        position: 'relative',
        borderWidth: 1,
        borderColor: 'rgba(0,0,0,0)',
        overflow: 'hidden',
        marginBottom: px2dp(6),
        borderRadius: px2dp(2)
    },

    mapTypeImg: {
        width: px2dp(112),
        height: px2dp(88),
        borderColor: colors.borderColor,
        borderWidth: onePx,
    },

    mapCheckedRow: {
        position: 'absolute',
        left: 0,
        bottom: 0,
        width: '100%',
        height: px2dp(18),
        zIndex: 999,
        backgroundColor: colors.themeColor,
        justifyContent: 'center',
        alignItems: 'center'
    },

    mapCheckedIcon: {
        width: px2dp(18),
        height: px2dp(18),
        tintColor: '#FFF'
    },

    rowIcon1: {
        width: px2dp(44),
        height: px2dp(44),
        borderRadius: px2dp(22)
    },

    rowIcon: {
        width: px2dp(48),
        height: px2dp(48),

    },

    optionBtn: {
        height: '100%',
        justifyContent: 'center',
        alignItems: 'center',
        paddingHorizontal: px2dp(12)
    },

    optionRightIcon: {
        width: px2dp(28),
        height: px2dp(28),
        tintColor: '#909399'
    },

    iconBorder: {
        width: px2dp(48),
        height: px2dp(48),
        borderRadius: px2dp(24),
        borderWidth: 2,
        borderColor: '#909399',
        justifyContent: 'center',
        alignItems: 'center',
        marginHorizontal: px2dp(6)
    }
})