import { DeviceEventEmitter } from "react-native";
import { deepCopy, filterSqlRows, getCurrentDateNs, isArray, isEmpty, toast, toastShort, uuid } from "../utils"
import redux from './../redux/store';
import { BjTypeActualMeasurementResearch, BjTypeActualMeasurementResearchTableRow, BjTypeCommonResearch, BjTypeCommunityProfileResearch, BjTypeFastRecordV1, BjTypeFrequencyTableRow, BjTypeResearchNameDict, BjTypeSampleLineResearch, BjTypeSampleSquareResearch, BjTypeSpeciesBookTableRow, BjTypeUserMsg } from "../utils/types";
import mockAction from "./mockAction";
import {
    BjInstanceActualMeasurementResearch,
    BjInstanceCommunityProfileResearch,
    BjInstanceFastRecordV1,
    BjInstanceFrequencyTableRow,
    BjInstanceResearchConnection,
    BjInstanceSampleLineResearch,
    BjInstanceSampleSquareResearch
} from "../database/Instance";
import DataBaseTableName from "./../database/DataBaseTableName";

// import { adaptAPIAndName } from "../utils/adapt";

declare namespace Service {
    interface Option {
        ykk_code: number
        data?: {
            info?: string
        }
        msg: string
        origin?: string
    }
    interface ListResult {
        ykk_code: number
        data?: {
            list?: Array<any>
        }
        msg: string
        origin?: string
    }
    interface ListSearchResult {
        ykk_code: number
        data?: {
            info?: any
        }
        msg: string
        origin?: string
    }
}


interface TypeQueryParams {
    pageSize?: number,
    pageNum?: number,
    researchId?: string
    id?: string
    isLocalDelete?: '0' | '1',
    serialNumberAndCode?: string
    referenceNumberAndCode?: string
    type?: BjTypeResearchNameDict
    blockIdList?: string
}

const getUserId = (): string => {
    try {
        const userMsg: BjTypeUserMsg = redux.getState().userMsg;
        return userMsg.userInfo.id ? userMsg.userInfo.id : 'TEMP_USER_ID'
    } catch (e) {
        return 'TEMP_USER_ID';
    }
};

/**
* 处理调查参数
* @param params 
*/
const filterResearchParams = (params) => {
    if (isEmpty(params.id)) {
        params.id = uuid();
    }
    if (isEmpty(params.createUserId)) {
        params.createUserId = getUserId();
    }
    if (isEmpty(params.createDate)) {
        params.createDate = getCurrentDateNs();
    }
    if ((params.isLocalDelete == null || params.isLocalDelete == undefined) && isEmpty(params.isLocalDelete)) {
        params.isLocalDelete = '0';
    }
    return params
};

/**
 * 保存到调查公共表里面去
 * @param type 本地数据的业务类型
 * @param params 
 */
const saveToCommonResearchTable = (
    type: BjTypeResearchNameDict,
    params: BjTypeCommunityProfileResearch & BjTypeActualMeasurementResearch & BjTypeSampleLineResearch & BjTypeSampleSquareResearch,
    isEdit: boolean
) => {
    if (isEmpty(params.serialNumberAndCode)) {
        // if (!isEmpty(params.title)) {
        //     params.serialNumberAndCode = params.serialNumberAndCode;
        // } else if (!isEmpty(params.speciesName)) {
        //     params.serialNumberAndCode = params.speciesName;
        // }
    }
    let commonResearchParams: BjTypeCommonResearch = {
        id: params.id,
        createUserId: params.createUserId,
        type: type,
        researchId: params.id,
        serialNumberAndCode: params.serialNumberAndCode ? params.serialNumberAndCode : "",
        createDate: params.createDate,
        finishDate: params.finishDate,
        isLocalDelete: params.isLocalDelete,
        updateDate: getCurrentDateNs(),
        imageList: params.researchAreaImageList,
        remark: params.remark,
        targetSpeciesLiveType: "arbor",
        belongType: 'self'
    };
    if(type == 'sampleSquareResearch'){
        commonResearchParams.targetSpeciesLiveType = params.targetSpeciesLiveType;
    }
    if(!isEmpty(params.belongType)){
        commonResearchParams.belongType = params.belongType;
    }
    console.log("写入调查总表的参数是----->", commonResearchParams)
    if (isEdit) {
        mockAction.updateRowToDataBase(DataBaseTableName.researchCommonTable, commonResearchParams)
            .then(res => {
                console.log("本地公共调查数据-更新成功")
            })
            .catch(err => {
                console.log("err", err)
                toastShort("调查更新失败，请联系管理员！")
            })
    } else {
        mockAction.saveDataToDataBase(DataBaseTableName.researchCommonTable, commonResearchParams)
            .then(res => {
                console.log("本地公共调查数据-新增成功")
            })
            .catch(err => {
                console.log("err", err)
                toastShort("调查创建失败，请联系管理员！")
            })
    }
};

/**
 * 
 * @param params 接口参数
 * @param res sqlite回调
 */
const gegeratePromiseResult = (params, res): Promise<Service.Option> => {
    console.log("测试----->gegeratePromiseResult", params, res)
    let resultBody = {
        ykk_code: 10000,
        msg: 'ok',
        data: {},
        origin: 'local-device'
    }
    return new Promise(async (resolve, reject) => {
        if (res && (!isEmpty(res.rows) || "成功")) {
            resultBody.data = { info: params ? params.id : '' }
        } else {
            resultBody.ykk_code = 500;
            resultBody.msg = "操作失败"
        }
        resolve(resultBody)
    });
};

const generatePromiseResultList = (res): Promise<Service.ListResult> => {
    // console.log("generatePromiseResultList")
    let resultBody = {
        ykk_code: 10000,
        msg: 'ok',
        data: {
            list: []
        },
        origin: 'local-device'
    }
    return new Promise(async (resolve, reject) => {
        if (res && !isEmpty(res.rows)) {
            resultBody.data.list = filterSqlRows(res)
        } else {
            resultBody.ykk_code = 5000;
            resultBody.msg = "操作失败"
        }
        resolve(resultBody)
    });
};


/**
 * 批量更新数据
 * @param tableName 
 * @param paramsList 
 * @returns 
 */
const updateDataToDataBaseMultiple = (tableName: string, paramsList: Array<Object>) => {
    paramsList.forEach(newParams => {
        mockAction.updateRowToDataBase(tableName, newParams)
            .then(res => {
                console.log("updateDataToDataBaseMultiple->更新成功", res)
            })
            .catch(err => {
                console.log("updateDataToDataBaseMultiple->更新失败", err)
            })
    });
};

const justCallbackOption = (list): Promise<Service.Option> => {
    let resultBody = {
        ykk_code: 10000,
        msg: 'ok',
        data: list
    }
    return new Promise(async (resolve, reject) => {
        resolve(resultBody)
    });
};

const localSevice = {
    /**
     * 删除公共调查列表
     * @param params 
     * @returns 
     */
    deleteCommonResearchListV1: async (params: TypeQueryParams): Promise<Service.Option> => {
        try {
            const currentCommonResearchRes = await mockAction.queryData(DataBaseTableName.researchCommonTable, params);
            const currentCommonResearch = filterSqlRows(currentCommonResearchRes)[0];
            console.log("currentCommonResearch", currentCommonResearch);
            const deleteParams = currentCommonResearch;
            deleteParams.isLocalDelete = '1';
            const res = await mockAction.updateRowToDataBase(DataBaseTableName.researchCommonTable, deleteParams)
            params.serialNumberAndCode = deleteParams.serialNumberAndCode;
            params = filterResearchParams(params)
            // const adaptResultForResearchQuery = adaptAPIAndName(params.type, 'query', 'research-data');
            // const adaptResultForResearchOption = adaptAPIAndName(params.type, 'option', 'research-data');
            // if (adaptResultForResearchQuery && adaptResultForResearchOption) {
            //     const currentResearchRes = await mockAction.queryData(adaptResultForResearchQuery.tableName, { id: params.id })
            //     if (currentResearchRes) {
            //         const researchList = filterSqlRows(currentResearchRes);
            //         if (researchList && researchList.length) {
            //             const currentResearch: TypeBirdResearchLineV1 = researchList[0];
            //             //@ts-ignore
            //             currentResearch.isLocalDelete = '1';
            //             const updateCurrentResearchRes = mockAction.updateRowToDataBase(adaptResultForResearchOption.tableName, currentResearch)
            //             console.log("updateCurrentResearchRes----->对调查本身的删除结果是----->", filterSqlRows(updateCurrentResearchRes))
            //         }
            //     }
            // }
            // const taskListRes = mockAction.queryData(DataBaseTableName.uploadTaskDataTable, { type: params.type, serialNumberAndCode: params.serialNumberAndCode })
            // const taskList: Array<TypeUploadTaskV1> = filterSqlRows(taskListRes)
            // if (taskList && taskList.length) {
            //     console.log("删除调查时，对所有创建的备份任务的查询------>", taskList);
            //     taskList.forEach(task => {
            //         mockAction.removeDataToDataBase(DataBaseTableName.uploadTaskDataTable, task.id)
            //             .then(res => {
            //                 console.log("公共调查删除时，附带删除的备份任务, 结果是------>", res)
            //             })
            //             .catch(err => {
            //                 console.log("公共调查删除时，附带删除的备份任务, 结果是- 删除失败", err)
            //             })
            //     })
            // } else {
            //     console.log("删除调查时，没有找到备份任务")
            // }
            return gegeratePromiseResult(null, "成功");  //删除就不添加任务了，此处做直接屏蔽处理
        } catch (e) {
            console.log("删除公共调查失败了------>", e)
        }
    },

    optionNootV1: async (params: BjTypeFastRecordV1): Promise<Service.Option> => {
        let isEdit = params.id ? true : false;  //判断是否是调查，根据id判断
        //合并参数，避免缺字段导致数据库报错
        params = {
            ...BjInstanceFastRecordV1,
            ...params,
        };
        params = filterResearchParams(params);
        let res = null;
        if (isEdit) {
            res = await mockAction.updateRowToDataBase(DataBaseTableName.nootBookTable, params);
        } else {
            res = await mockAction.saveDataToDataBase(DataBaseTableName.nootBookTable, params);
        }
        return gegeratePromiseResult(params, res);
    },

    /*************** 群落概况 ***************/

    getCommunityProfileResearchDetailsV1: async (params: TypeQueryParams): Promise<Service.ListResult> => {
        const res = await mockAction.queryData(DataBaseTableName.communityProfileResearchTable, params);
        return generatePromiseResultList(res);
    },

    /**
    * 新增或编辑群落概况调查
    * @param params 
    * @returns 
    */
    optionCommunityProfileResearchV1: async (params: BjTypeCommunityProfileResearch): Promise<Service.Option> => {
        const currentDataTableName = DataBaseTableName.communityProfileResearchTable;
        let isEdit = params.id ? true : false;
        //合并参数，避免缺字段导致数据库报错
        params = {
            ...BjInstanceCommunityProfileResearch,
            ...params,
        };
        if (!isEdit) {
            params.id = uuid();
            const checkIsCurrentResearchCodeExistRes = await mockAction.queryData(currentDataTableName, { serialNumberAndCode: params.serialNumberAndCode, isLocalDelete: '0', createUserId: getUserId() });
            const checkIsCurrentResearchCodeExist = filterSqlRows(checkIsCurrentResearchCodeExistRes);
            if (checkIsCurrentResearchCodeExist.length) {
                return {
                    ykk_code: 500,
                    msg: "该调查编码在本设备中已存在，请您重新输入",
                }
            }
        }
        params = filterResearchParams(params);
        saveToCommonResearchTable('communityProfileResearch', params, isEdit)
        let res = null;
        if (isEdit) {
            res = await mockAction.updateRowToDataBase(currentDataTableName, params);
        } else {
            res = await mockAction.saveDataToDataBase(currentDataTableName, params);
        }
        return gegeratePromiseResult(params, res);
    },

    /**************** 全测法 ****************/

    queryResearchConnection: async (params: TypeQueryParams): Promise<Service.ListResult> => {
        const res = await mockAction.queryData(DataBaseTableName.researchConnectionTable, params);
        return generatePromiseResultList(res);
    },

    getActualMeasurementResearchDetailsV1: async (params: TypeQueryParams): Promise<Service.ListResult> => {
        const res = await mockAction.queryData(DataBaseTableName.actualMeasurementResearchTable, params);
        return generatePromiseResultList(res);
    },

    /**
    * 新增或编辑全测法调查
    * @param params 
    * @returns 
    */
    optionActualMeasurementResearchV1: async (params: BjTypeActualMeasurementResearch): Promise<Service.Option> => {
        const currentDataTableName = DataBaseTableName.actualMeasurementResearchTable;
        let isEdit = params.id ? true : false;
        params = {
            ...BjInstanceActualMeasurementResearch,
            ...params,
        };
        if (!isEdit) {
            params.id = uuid();
            const checkIsCurrentResearchCodeExistRes = await mockAction.queryData(currentDataTableName, { serialNumberAndCode: params.serialNumberAndCode, isLocalDelete: '0', createUserId: getUserId() });
            const checkIsCurrentResearchCodeExist = filterSqlRows(checkIsCurrentResearchCodeExistRes);
            if (checkIsCurrentResearchCodeExist.length) {
                return {
                    ykk_code: 500,
                    msg: "该调查编码在本设备中已存在，请您重新输入",
                }
            }
        }
        params = filterResearchParams(params);
        saveToCommonResearchTable('actualMeasurementResearch', params, isEdit)
        let res = null;
        if (isEdit) {
            res = await mockAction.updateRowToDataBase(currentDataTableName, params);
        } else {
            res = await mockAction.saveDataToDataBase(currentDataTableName, params);
        }
        return gegeratePromiseResult(params, res);
    },

    /**
     * 新增/编辑
     * @param params 
     * @returns 
     */
    quertResearchConnection: async (params): Promise<Service.Option> => {
        const currentDataTableName = DataBaseTableName.researchConnectionTable;
        let isEdit = params.id ? true : false;
        params = {
            ...BjInstanceResearchConnection,
            ...params,
        };
        if (!isEdit) {
            params.id = uuid();
        }
        let res = null;
        if (isEdit) {
            res = await mockAction.updateRowToDataBase(currentDataTableName, params);
        } else {
            res = await mockAction.saveDataToDataBase(currentDataTableName, params);
        }
        return gegeratePromiseResult(params, res);
    },

    getActualMeasurementResearchTableRowListV1: async (params: TypeQueryParams): Promise<Service.ListResult> => {
        params.isLocalDelete = '0';
        const res = await mockAction.queryData(DataBaseTableName.actualMeasurementResearchSubTable, params, null, 'desc');
        return generatePromiseResultList(res);
    },

    optionActualMeasurementResearchTableRowV1: async (paramsList: Array<BjTypeActualMeasurementResearchTableRow>): Promise<Service.Option> => {
        let isEdit = false;
        const checkParamsList = deepCopy(paramsList);
        if (checkParamsList[0] && !isEmpty(checkParamsList[0].id)) {
            isEdit = true;
        }
        const currentResearchRes = await mockAction.queryData(DataBaseTableName.actualMeasurementResearchTable, { id: paramsList[0].researchId });
        const currentResearch: BjTypeActualMeasurementResearch = filterSqlRows(currentResearchRes)[0];
        paramsList.forEach(params => {
            params.serialNumberAndCode = currentResearch.serialNumberAndCode;
            if (isEmpty(params.id)) {
                params.id = uuid();
                params.createDate = getCurrentDateNs();
            } else {
                params.editDate = getCurrentDateNs();
            }
        })
        let optionResult = null;
        if (isEdit) {
            optionResult = await updateDataToDataBaseMultiple(DataBaseTableName.actualMeasurementResearchSubTable, paramsList);
            return justCallbackOption(paramsList)
        } else {
            optionResult = await mockAction.saveDataToDataBaseMultiple(DataBaseTableName.actualMeasurementResearchSubTable, paramsList);
        }
        return gegeratePromiseResult(paramsList[0], optionResult);
    },

    deleteActualMeasurementResearchTableRowV1: async (params: BjTypeActualMeasurementResearchTableRow): Promise<Service.Option> => {
        params.isLocalDelete = '1';
        const res = await mockAction.updateRowToDataBase(DataBaseTableName.actualMeasurementResearchSubTable, params)
        params = filterResearchParams(params)
        return gegeratePromiseResult(null, "成功");
    },


    ///
    getSampleSquareResearchDetailstV1: async (params: TypeQueryParams): Promise<Service.ListResult> => {
        const res = await mockAction.queryData(DataBaseTableName.sampleSquareResearchTable, params);
        return generatePromiseResultList(res);
    },

    /**
    * 新增或编辑全测法调查
    * @param params 
    * @returns 
    */
     optionSampleSquareResearchV1: async (params: BjTypeSampleSquareResearch): Promise<Service.Option> => {
        const currentDataTableName = DataBaseTableName.sampleSquareResearchTable;
        let isEdit = params.id ? true : false;
        params = {
            ...BjInstanceSampleSquareResearch,
            ...params,
        };
        if (!isEdit) {
            params.id = uuid();
            const checkIsCurrentResearchCodeExistRes = await mockAction.queryData(currentDataTableName, { serialNumberAndCode: params.serialNumberAndCode, isLocalDelete: '0', createUserId: getUserId() });
            const checkIsCurrentResearchCodeExist = filterSqlRows(checkIsCurrentResearchCodeExistRes);
            if (checkIsCurrentResearchCodeExist.length) {
                return {
                    ykk_code: 500,
                    msg: "该调查编码在本设备中已存在，请您重新输入",
                }
            }
        }
        params = filterResearchParams(params);
        saveToCommonResearchTable('sampleSquareResearch', params, isEdit)
        let res = null;
        if (isEdit) {
            res = await mockAction.updateRowToDataBase(currentDataTableName, params);
        } else {
            res = await mockAction.saveDataToDataBase(currentDataTableName, params);
        }
        return gegeratePromiseResult(params, res);
    },


    getSampleSquareResearchTableRowListV1: async (params: TypeQueryParams): Promise<Service.ListResult> => {
        params.isLocalDelete = '0';
        const res = await mockAction.queryData(DataBaseTableName.sampleSquareResearchSubTable, params, null, 'desc');
        return generatePromiseResultList(res);
    },

    optionSampleSquareResearchTableRowV1: async (paramsList: Array<BjTypeActualMeasurementResearchTableRow>): Promise<Service.Option> => {
        let isEdit = false;
        const checkParamsList = deepCopy(paramsList);
        if (checkParamsList[0] && !isEmpty(checkParamsList[0].id)) {
            isEdit = true;
        }
        const currentResearchRes = await mockAction.queryData(DataBaseTableName.sampleSquareResearchTable, { id: paramsList[0].researchId });
        const currentResearch: BjTypeActualMeasurementResearch = filterSqlRows(currentResearchRes)[0];
        paramsList.forEach(params => {
            params.serialNumberAndCode = currentResearch.serialNumberAndCode;
            if (isEmpty(params.id)) {
                params.id = uuid();
                params.createDate = getCurrentDateNs();
            } else {
                params.editDate = getCurrentDateNs();
            }
        })
        let optionResult = null;
        if (isEdit) {
            optionResult = await updateDataToDataBaseMultiple(DataBaseTableName.sampleSquareResearchSubTable, paramsList);
            return justCallbackOption(paramsList)
        } else {
            optionResult = await mockAction.saveDataToDataBaseMultiple(DataBaseTableName.sampleSquareResearchSubTable, paramsList);
        }
        return gegeratePromiseResult(paramsList[0], optionResult);
    },

    deleteSampleSquareResearchTableRowV1: async (params: BjTypeActualMeasurementResearchTableRow): Promise<Service.Option> => {
        params.isLocalDelete = '1';
        const res = await mockAction.updateRowToDataBase(DataBaseTableName.sampleSquareResearchSubTable, params)
        params = filterResearchParams(params)
        return gegeratePromiseResult(null, "成功");
    },

    ///
    getSampleLineResearchDetailstV1: async (params: TypeQueryParams): Promise<Service.ListResult> => {
        const res = await mockAction.queryData(DataBaseTableName.sampleLineResearchTable, params);
        return generatePromiseResultList(res);
    },

    /**
    * 新增或编辑全测法调查
    * @param params 
    * @returns 
    */
     optionSampleLineResearchV1: async (params: BjTypeSampleLineResearch): Promise<Service.Option> => {
        const currentDataTableName = DataBaseTableName.sampleLineResearchTable;
        let isEdit = params.id ? true : false;
        params = {
            ...BjInstanceSampleLineResearch,
            ...params,
        };
        if (!isEdit) {
            params.id = uuid();
            const checkIsCurrentResearchCodeExistRes = await mockAction.queryData(currentDataTableName, { serialNumberAndCode: params.serialNumberAndCode, isLocalDelete: '0', createUserId: getUserId() });
            const checkIsCurrentResearchCodeExist = filterSqlRows(checkIsCurrentResearchCodeExistRes);
            if (checkIsCurrentResearchCodeExist.length) {
                return {
                    ykk_code: 500,
                    msg: "该调查编码在本设备中已存在，请您重新输入",
                }
            }
        }
        params = filterResearchParams(params);
        saveToCommonResearchTable('sampleLineResearch', params, isEdit)
        let res = null;
        if (isEdit) {
            res = await mockAction.updateRowToDataBase(currentDataTableName, params);
        } else {
            res = await mockAction.saveDataToDataBase(currentDataTableName, params);
        }
        return gegeratePromiseResult(params, res);
    },

    getSampleLineResearchTableRowListV1: async (params: TypeQueryParams): Promise<Service.ListResult> => {
        params.isLocalDelete = '0';
        const res = await mockAction.queryData(DataBaseTableName.sampleLineResearchSubTable, params, null, 'desc');
        return generatePromiseResultList(res);
    },

    optionSampleLineResearchTableRowV1: async (paramsList: Array<BjTypeActualMeasurementResearchTableRow>): Promise<Service.Option> => {
        let isEdit = false;
        const checkParamsList = deepCopy(paramsList);
        if (checkParamsList[0] && !isEmpty(checkParamsList[0].id)) {
            isEdit = true;
        }
        const currentResearchRes = await mockAction.queryData(DataBaseTableName.sampleLineResearchTable, { id: paramsList[0].researchId });
        const currentResearch: BjTypeSampleLineResearch = filterSqlRows(currentResearchRes)[0];
        paramsList.forEach(params => {
            params.serialNumberAndCode = currentResearch.serialNumberAndCode;
            if (isEmpty(params.id)) {
                params.id = uuid();
                params.createDate = getCurrentDateNs();
            } else {
                params.editDate = getCurrentDateNs();
            }
        })
        let optionResult = null;
        if (isEdit) {
            optionResult = await updateDataToDataBaseMultiple(DataBaseTableName.sampleLineResearchSubTable, paramsList);
            return justCallbackOption(paramsList)
        } else {
            optionResult = await mockAction.saveDataToDataBaseMultiple(DataBaseTableName.sampleLineResearchSubTable, paramsList);
        }
        return gegeratePromiseResult(paramsList[0], optionResult);
    },

    deleteSampleLineResearchTableRowV1: async (params: BjTypeActualMeasurementResearchTableRow): Promise<Service.Option> => {
        params.isLocalDelete = '1';
        const res = await mockAction.updateRowToDataBase(DataBaseTableName.sampleLineResearchSubTable, params)
        params = filterResearchParams(params)
        return gegeratePromiseResult(null, "成功");
    },

    getFrequencyTableListV1: async (params: TypeQueryParams): Promise<Service.ListResult> => {
        params.isLocalDelete = '0';
        const res = await mockAction.queryData(DataBaseTableName.frequencyTable, params, null, 'desc');
        return generatePromiseResultList(res);
    },

    optionFrequencyTableRowV1: async (paramsList: Array<BjTypeFrequencyTableRow>): Promise<Service.Option> => {
        let isEdit = false;
        const checkParamsList = deepCopy(paramsList);
        if (checkParamsList[0] && !isEmpty(checkParamsList[0].id)) {
            isEdit = true;
        }
        paramsList.forEach(params => {
            if (isEmpty(params.id)) {
                params.id = uuid();
                //@ts-ignore
                params.createDate = getCurrentDateNs();
            }
        })
        let optionResult = null;
        if (isEdit) {
            optionResult = await updateDataToDataBaseMultiple(DataBaseTableName.frequencyTable, paramsList);
            return justCallbackOption(paramsList)
        } else {
            optionResult = await mockAction.saveDataToDataBaseMultiple(DataBaseTableName.frequencyTable, paramsList);
        }
        return gegeratePromiseResult(paramsList[0], optionResult);
    },

    deleteFrequencyTableRowV1: async (params: BjTypeFrequencyTableRow): Promise<Service.Option> => {
        params.isLocalDelete = '1';
        const res = await mockAction.updateRowToDataBase(DataBaseTableName.frequencyTable, params)
        params = filterResearchParams(params)
        return gegeratePromiseResult(null, "成功");
    },

    getSpeciesBookTableListV1: async (params: TypeQueryParams): Promise<Service.ListResult> => {
        params.isLocalDelete = '0';
        const res = await mockAction.queryData(DataBaseTableName.speciesBookTable, params, null, 'desc');
        return generatePromiseResultList(res);
    },

    optionSpeciesBookTableRowV1: async (paramsList: Array<BjTypeSpeciesBookTableRow>): Promise<Service.Option> => {
        let isEdit = false;
        const checkParamsList = deepCopy(paramsList);
        if (checkParamsList[0] && !isEmpty(checkParamsList[0].id)) {
            isEdit = true;
        }
        paramsList.forEach(params => {
            if (isEmpty(params.id)) {
                params.id = uuid();
                //@ts-ignore
                params.createDate = getCurrentDateNs();
            }
        })
        let optionResult = null;
        if (isEdit) {
            optionResult = await updateDataToDataBaseMultiple(DataBaseTableName.speciesBookTable, paramsList);
            return justCallbackOption(paramsList)
        } else {
            optionResult = await mockAction.saveDataToDataBaseMultiple(DataBaseTableName.speciesBookTable, paramsList);
        }
        return gegeratePromiseResult(paramsList[0], optionResult);
    },

    deleteSpeciesBookTableRowV1: async (params: BjTypeSpeciesBookTableRow): Promise<Service.Option> => {
        params.isLocalDelete = '1';
        const res = await mockAction.updateRowToDataBase(DataBaseTableName.speciesBookTable, params)
        params = filterResearchParams(params)
        return gegeratePromiseResult(null, "成功");
    },
}


export default localSevice;