import { isArray, isEmpty } from "../utils"

var isNumber = function isNumber(value) {
    return typeof value === 'number' && isFinite(value);
}


/**
 * 
 * @param {String} sqlStatement  SQL表达式
 * @param {Array} args 参数
 * @returns {Promise}
 */
const DoSQL = (sqlStatement, args = []) => {
    return new Promise((resolve, reject) => {
        //@ts-ignore
        global.db.transaction((ctx) => {
            ctx.executeSql(
                sqlStatement,
                args,
                (tx, res) => {
                    resolve(res)
                },
                (error) => {
                    console.log("DoSQL---->err", error)
                    reject(error)
                }
            )
        })
    })
}

const deleteEmptyValueOfKey = (object) => {
    for (var key in object) {
        if (isEmpty(object[key])) {
            delete object[key]
        }
    }
    return object;
};

/**
 * 对象解构生成插入数据SQL
 * @param tableName 表名
 * @param dataObject 参数
 */
const generateInsertSQLStatement = (tableName, dataObject) => {
    // dataObject = deleteEmptyValueOfKey(dataObject);
    const { keys, values } = Object;
    let SQLStatement = '';
    let keyStr = '';
    let valueStr = '';
    let len = keys(dataObject).length;
    keys(dataObject).forEach((key, index) => {
        if (index == len - 1) {
            keyStr = keyStr + key;
        } else {
            keyStr = keyStr + key + ', '
        }
    })
    values(dataObject).forEach((value, index) => {
        if (isEmpty(value)) {
            value = ''
        }
        let _value = null;
        if (isArray(value)) {
            // console.log('这是数组', `"${JSON.stringify(value)}"`)
            //@ts-ignore
            _value = value.toString();
        } else {
            if (value == null || value == undefined) {
                _value = value
            } else {
                if (typeof (value) == 'number') {
                    _value = value
                } else {
                    value = value + ''
                    //@ts-ignore
                    value = value.replace(/\"/g, "'");
                    _value = `"${value}"`;
                }
            }
        }
        if (index == len - 1) {
            valueStr = valueStr + _value;
        } else {
            valueStr = valueStr + _value + ', '
        }
    })
    console.log("----", keyStr, valueStr)
    SQLStatement = `INSERT INTO ${tableName} (${keyStr}) VALUES (${valueStr})`;
    return SQLStatement;
};


const generateInsertSQLMultiple = (tableName, dataObjectList: Array<Object>) => {
    const { keys, values } = Object;
    let SQLStatement = '';
    let keyStr = '';
    let valueStr = '';
    const dataObject = dataObjectList[0]
    const dataObjectListLength = dataObjectList.length;
    const len = keys(dataObject).length;
    keys(dataObject).forEach((key, index) => {
        if (index == len - 1) {
            keyStr = keyStr + key;
        } else {
            keyStr = keyStr + key + ', '
        }
    })
    dataObjectList.forEach((ele, eleIndex) => {
        let tempValueStr = ' ('
        values(ele).forEach((value, index) => {
            if (isEmpty(value)) {
                value = ''
            }
            let _value = null;
            if (isArray(value)) {
                //@ts-ignore
                _value = value.toString();
            } else {
                if (value == null || value == undefined) {
                    value = value
                } else {
                    if (typeof (value) == 'number') {
                        _value = value
                    } else {
                        value = value + ''
                        //@ts-ignore
                        value = value.replace(/\"/g, "'");
                        _value = `"${value}"`;
                    }
                }
            }
            if (index == len - 1) {
                tempValueStr = tempValueStr + _value;
            } else {
                tempValueStr = tempValueStr + _value + ', '
            }
        });
        if (eleIndex < dataObjectListLength - 1) {
            valueStr = valueStr + tempValueStr + '),'
        } else {
            valueStr = valueStr + tempValueStr + ')'
        }
    })
    SQLStatement = `INSERT INTO ${tableName} (${keyStr}) VALUES ${valueStr}`;
    console.log("批量插入SQL", SQLStatement)
    return SQLStatement;
};

const FIND_IN_SET = (id_str: string, ids: string) => {
    let idsArr = ids.split(',');
    let resultSQL = '(';
    idsArr.forEach((id, index) => {
        if (!isEmpty(id)) {
            if (index < idsArr.length - 1) {
                resultSQL = resultSQL + `${id_str} like '%${id}%' or `
            } else {
                resultSQL = resultSQL + `${id_str} like '%${id}%')`
            }
        }
    });
    return resultSQL;
}

const mockAction = {

    /**
     * 
     * @param tableName 
     * @param filters 
     * @param offset 
     * @param likesFilters
     */
    queryByMultipleLike: (tableName, likesFilters, findType?: 'findLeft' | 'findAll' | string, filters?, offset?, sortMode?: 'asc' | 'desc', sortChart?: string) => {
        if (isEmpty(sortMode)) {
            sortMode = 'desc';
        }
        if (isEmpty(sortChart)) {
            sortChart = 'createDate'
        }
        let querySQL = `SELECT * from ${tableName}`;
        const { keys, values } = Object;
        let likeSQL = '';
        const likeKeys = keys(likesFilters);
        const likeValues = values(likesFilters);
        likeKeys.forEach((key, index) => {
            if (index < likeKeys.length - 1) {
                if (findType == 'findLeft') {
                    likeSQL = likeSQL + `${key} like '${likeValues[index]}%' or `
                } else {
                    likeSQL = likeSQL + `${key} like '%${likeValues[index]}%' or `
                }
            } else {
                if (findType == 'findLeft') {
                    likeSQL = likeSQL + `${key} like '${likeValues[index]}%')`
                } else {
                    likeSQL = likeSQL + `${key} like '%${likeValues[index]}%')`
                }
            }
        });
        if (!isEmpty(likeSQL)) {
            querySQL = querySQL + ' where (' + likeSQL;
        };
        let fileterSQL = '';
        if (!isEmpty(filters) && keys(filters).length > 0) {
            fileterSQL = ` AND `
            keys(filters).forEach((key, index) => {
                //@ts-ignore
                fileterSQL = fileterSQL + key + ' = ' + (isNumber(values(filters)[index]) ? values(filters)[index] : `"${values(filters)[index]}"`);
                if (index < keys(filters).length - 1) {
                    fileterSQL = fileterSQL + ' and '
                }
            })
        }
        if (!isEmpty(fileterSQL)) {
            querySQL = querySQL + fileterSQL;
        };
        let limitSQL = '';
        if (offset) {
            limitSQL = ` limit ${(offset - 1) * 10}, ${offset * 10}`;
            if (fileterSQL) {
                querySQL = querySQL + fileterSQL + ` order by ${sortChart} ${sortMode}`;
            } else {
                querySQL = querySQL + ` order by ${sortChart} ${sortMode}`;
            }
            if (limitSQL) {
                querySQL = querySQL + limitSQL
            }
        } else {
            querySQL = querySQL + fileterSQL + ` order by ${sortChart} ${sortMode}`
        }
        console.log("fileterSQL---->", fileterSQL)
        console.log("querySQL", querySQL)
        return DoSQL(querySQL);
    },


    /**
     * 
     * @param tableName 
     * @param filters 
     * @param offset 
     * @param likesFilters
     */
    queryByMultipleLike1: (tableName, likesFilters, findType?: 'findLeft' | 'findAll' | string, filters?) => {
        let querySQL = `SELECT * from ${tableName}`;
        const { keys, values } = Object;
        let likeSQL = '';
        const likeKeys = keys(likesFilters);
        const likeValues = values(likesFilters);
        likeKeys.forEach((key, index) => {
            if (index < likeKeys.length - 1) {
                if (findType == 'findLeft') {
                    likeSQL = likeSQL + `${key} like '${likeValues[index]}%' or `
                } else {
                    likeSQL = likeSQL + `${key} like '%${likeValues[index]}%' or `
                }
            } else {
                if (findType == 'findLeft') {
                    likeSQL = likeSQL + `${key} like '${likeValues[index]}%')`
                } else {
                    likeSQL = likeSQL + `${key} like '%${likeValues[index]}%')`
                }
            }
        });
        if (!isEmpty(likeSQL)) {
            querySQL = querySQL + ' where (' + likeSQL;
        };
        let fileterSQL = '';
        if (!isEmpty(filters) && keys(filters).length > 0) {
            console.log("filters----->", filters)
            fileterSQL = ` AND `
            keys(filters).forEach((key, index) => {
                //@ts-ignore
                fileterSQL = fileterSQL + key + ' = ' + (isNumber(values(filters)[index]) ? values(filters)[index] : `"${values(filters)[index]}"`);
                if (index < keys(filters).length - 1) {
                    fileterSQL = fileterSQL + ' and '
                }
            })
        }
        if (!isEmpty(fileterSQL)) {
            querySQL = querySQL + fileterSQL;
        };
        let limitSQL = '';
        querySQL = querySQL + fileterSQL;
        console.log("fileterSQL---->", fileterSQL)
        console.log("querySQL----->", querySQL)
        return DoSQL(querySQL);
    },

    queryData: (tableName?, filters?, offset?, sortMode?: 'asc' | 'desc', sortChart?: string) => {
        try {
            if (isEmpty(sortMode)) {
                sortMode = 'desc';
            }
            if (isEmpty(sortChart)) {
                sortChart = 'createDate'
            }
            let querySQL = `SELECT * from ${tableName}`;
            const { keys, values } = Object;
            let fileterSQL = ''
            let limitSQL = '';
            if (keys(filters).length > 0) {
                fileterSQL = ` WHERE `
                keys(filters).forEach((key, index) => {
                    //@ts-ignore
                    fileterSQL = fileterSQL + key + ' = ' + (isNumber(values(filters)[index]) ? values(filters)[index] : `"${values(filters)[index]}"`);
                    if (index < keys(filters).length - 1) {
                        fileterSQL = fileterSQL + ' and '
                    }
                })
            }
            if (offset) {
                limitSQL = ` limit ${(offset - 1) * 10}, ${offset * 10}`;
                if (fileterSQL) {
                    querySQL = querySQL + fileterSQL + ` order by ${sortChart} ${sortMode}`;
                } else {
                    querySQL = querySQL + ` order by ${sortChart} ${sortMode}`;
                }
                if (limitSQL) {
                    querySQL = querySQL + limitSQL
                }
            } else {
                querySQL = querySQL + fileterSQL + ` order by ${sortChart} ${sortMode}`
            }
            console.log("querySQL", querySQL)
            return DoSQL(querySQL);
        } catch (e) {
            let querySQL = `SELECT * from ${tableName}`;
            return DoSQL(querySQL);
        }
    },

    queryDataByIds: (tableName, id_str, ids?: string) => {
        let querySQL = `SELECT * from ${tableName}`;
        console.log("这是测试find_in_set", FIND_IN_SET('id', ids))
        querySQL = `${querySQL} WHERE ${FIND_IN_SET(id_str, ids)}`;
        console.log("queryDataByIds", querySQL);
        return DoSQL(querySQL)
    },

    createTable: (sqlStatement: string) => {
        return DoSQL(sqlStatement);
    },

    saveDataToDataBase: (tableName, params) => {
        let sqlStatement = generateInsertSQLStatement(tableName, params)
        return DoSQL(sqlStatement)
    },

    saveDataToDataBaseMultiple: (tableName: string, paramsList: Array<Object>) => {
        let sqlStatement = generateInsertSQLMultiple(tableName, paramsList)
        console.log("saveDataToDataBaseMultiple", sqlStatement)
        return DoSQL(sqlStatement)
    },

    saveDataToDataBaseAsync: async (tableName, params) => {
        return new Promise(async (resolve, reject) => {
            try {
                let res = await mockAction.saveDataToDataBase(tableName, params)
                resolve(res)
            } catch (error) {
                reject(new Error('数据库操作失败' + error))
            }
        });
    },

    updateRowToDataBase: (tableName, newParams) => {
        const { keys, values } = Object;
        let sql = `UPDATE ${tableName} SET`
        const keysArr = keys(newParams);
        const valueArr = values(newParams);
        keysArr.forEach((key, index) => {
            if (key == 'id') {

            } else {
                let value = valueArr[index];
                let _value = null;
                if (isArray(value)) {
                    //@ts-ignore
                    _value = value.toString();
                } else {
                    if (value == null || value == undefined) {
                        value = value
                    } else {
                        if (typeof (value) == 'number') {
                            _value = value
                        } else {
                            value = value + ''
                            //@ts-ignore
                            value = value.replace(/\"/g, "'");
                            _value = `"${value}"`;
                        }
                    }
                }
                if (index == keysArr.length - 1) {
                    sql = sql + ` ${key} = ${_value}`;
                } else {
                    sql = sql + ` ${key} = ${_value},`;
                }
            }
        })
        if (sql[sql.length - 1] == ',') {
            sql = sql.substring(0, sql.length - 1);
        }
        sql = sql + ` where id = "${newParams.id}"`;
        console.log("得到的更新sql", sql)
        return DoSQL(sql);
    },

    clearTableRows: (tableName) => {
        let SQL = `DELETE FROM ${tableName}`;
        return DoSQL(SQL)
    },

    removeDataToDataBase: (tableName: string, deleteId: string) => {
        let sqlStatement = `DELETE FROM ${tableName} WHERE id = "${deleteId}"`
        console.log("removeDataToDataBase", sqlStatement)
        return DoSQL(sqlStatement)
    }

}


export default mockAction;