import { dispatchSerialNumber, getUserId, isEmpty, toast, toastShort } from './index';
/**
 * 生成器
 */

import { adaptAPIAndName } from "./adapt"
import { BjTypeAppConfig, BjTypeCommonResearch, BjTypeResearchNameDict } from "./types"
import redux from './../redux/store';
import mockAction from "./../sevices/mockAction";
import { filterSqlRows } from "./index";

const getAppConfig = (): BjTypeAppConfig => {
    return redux.getState().AppConfig;
};

/**
 * 自动编号生成器
 * @param type 调查类别
 * 1、查当前的调查默认编号前缀
 * 2、查当前的调查最新的调查实例
 * 3、确定当前调查是否是使用的默认编号规则
 * - 4 如果是默认编号规则，自动进位（但必须小于99999，超出不做自动编号处理）
 *  （自动进位的前提是还要找出来最后一位的编号相同的，且位数比当前编号大1的，也就是新位是否可用）
 * - 4 如果当前不是默认编号，选择符合条件的最小5位数
 */
const generateResearchCode = async (
    type: BjTypeResearchNameDict
) => {
    try {
        console.log("开始自动编号")
        const adaptResultForResearch = adaptAPIAndName(type, 'query', 'research-data');
        const appConfig: BjTypeAppConfig = getAppConfig();
        console.log("这是应用当前最新配置", appConfig)
        const currentDefualtResearchCode = appConfig[type];
        if (isEmpty(currentDefualtResearchCode)) {
            toastShort("当前调查类别暂无默认编号设置")
            return '';
        }
        console.log("currentDefualtResearchCode----->", currentDefualtResearchCode)
        const researchListQueryRes = await mockAction.queryData(adaptResultForResearch.tableName, { createUserId: getUserId()});
        const researchList: Array<BjTypeCommonResearch> = filterSqlRows(researchListQueryRes);
        let maxSerialNumber = '001';
        if (researchList && researchList.length) {
            const lastResearch: BjTypeCommonResearch = researchList[researchList.length - 1];
            let maxDefaultResearchCodeInstance: BjTypeCommonResearch = null;
            if (dispatchSerialNumber(lastResearch.serialNumberAndCode, 0) == currentDefualtResearchCode) {
                //最后一个调查是用的默认调查，则直接使用默认调查的前缀
                console.log("最后一个调查是用的默认调查-------->")
                maxDefaultResearchCodeInstance = lastResearch;
            } else {
                //最后一个调查用的不是默认调查
                console.log("最后一个调查用的不是默认调查------>")
            }

            researchList.forEach(ele => {
                let tempSerialNumber = Number(dispatchSerialNumber(ele.serialNumberAndCode, 1))
                if(tempSerialNumber >= Number(maxSerialNumber)){
                    //如果当前的序列号大于最大的序列号
                    tempSerialNumber = tempSerialNumber + 1;
                    // console.log("tempSerialNumber------>", tempSerialNumber)
                    maxSerialNumber = (tempSerialNumber + '').padStart(3, '0')
                }
                if (dispatchSerialNumber(ele.serialNumberAndCode, 0) == currentDefualtResearchCode) {
                    console.log("yes")
                    if (maxDefaultResearchCodeInstance) {
                        if (Number(dispatchSerialNumber(maxDefaultResearchCodeInstance.serialNumberAndCode, 1)) < Number(dispatchSerialNumber(ele.serialNumberAndCode, 1))) {
                            maxDefaultResearchCodeInstance = ele;
                        }
                    }
                } else {
                    console.log("no")
                }
            })
            console.log("maxDefaultResearchCodeInstance----->", maxDefaultResearchCodeInstance)
            if (!maxDefaultResearchCodeInstance) {
                console.log("ssss")
                return currentDefualtResearchCode + '-' + maxSerialNumber
            } else {
                return currentDefualtResearchCode + '-' + ((Number(dispatchSerialNumber(maxDefaultResearchCodeInstance.serialNumberAndCode, 1)) + 1) + '').padStart(3, '0')
            }
        } else {
            //如果还没有创建记录，就是用默认的配置，并从001开始
            return currentDefualtResearchCode + '-001'
        }
    } catch (e) {
        console.log("自动编号失败", e)
        return "-";
    }
}


export {
    generateResearchCode
}